(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     90581,       2211]
NotebookOptionsPosition[     81668,       2056]
NotebookOutlinePosition[     82061,       2072]
CellTagsIndexPosition[     82018,       2069]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Resummation and large order in quantum mechanics: the quartic oscillator\
\>", "Title",
 CellChangeTimes->{{3.4023051664278917`*^9, 3.4023051720018873`*^9}, {
  3.4041279642708263`*^9, 3.4041279685583076`*^9}, {3.530702564321499*^9, 
  3.530702569062932*^9}, {3.703172868186001*^9, 3.703172874642477*^9}, {
  3.704085951315933*^9, 3.704085957241831*^9}, {3.877510835119563*^9, 
  3.877510838850216*^9}, {3.8782040579904413`*^9, 3.878204062605647*^9}, {
  3.8782041229579*^9, 3.8782041260688*^9}, {3.878204168341083*^9, 
  3.878204172964119*^9}},ExpressionUUID->"00cf2cbc-c2a7-44f7-a290-\
c46b23a76398"],

Cell[CellGroupData[{

Cell["1. Loading the sequence", "Section",
 CellChangeTimes->{{3.844171450887299*^9, 3.844171452912423*^9}, {
  3.848641815011495*^9, 3.848641816243886*^9}, {3.849433075987344*^9, 
  3.8494330770065727`*^9}, {3.877934503568592*^9, 3.877934510746976*^9}, {
  3.877963441455147*^9, 3.8779634480867167`*^9}, {3.878204072765132*^9, 
  3.878204073637515*^9}},
 FontSize->36,ExpressionUUID->"35011f57-1904-45ac-9aaa-714f17b3f713"],

Cell["\<\
The data file quartic200.dat contains a list with the first 200 coefficients \
of the ground state energy of the quartic oscillator. These are obtained by \
using the software BenderWu by Sulejmanpasic and Unsal. By running the \
routine below we create a list, called qlist, with these 200 coefficients\
\>", "Text",
 CellChangeTimes->{{3.404128219025543*^9, 3.404128233779027*^9}, {
  3.7031750902539873`*^9, 3.703175091228704*^9}, {3.877934842862117*^9, 
  3.8779348897127028`*^9}, {3.877963455148971*^9, 3.877963517622142*^9}, {
  3.8779638258596973`*^9, 
  3.8779638431361923`*^9}},ExpressionUUID->"75dace61-bd05-45ef-a6ac-\
767814606278"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"$gmax", "=", "200"}], ";", 
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filename", "=", "\"\<quartic200.dat\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"fp", "=", 
   RowBox[{"OpenRead", "[", "filename", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"qlist", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"line", "=", 
   RowBox[{"ReadLine", "[", "fp", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"line", "=!=", "EndOfFile"}], "&&", 
       RowBox[{"g", "<=", "$gmax"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"qlist", "=", 
        RowBox[{"Append", "[", 
         RowBox[{"qlist", ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"q", "[", "g", "]"}], "=", 
           RowBox[{"ToExpression", "[", "line", "]"}]}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"line", "=", 
        RowBox[{"ReadLine", "[", "fp", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"g", "++"}], ";"}]}], "]"}], ",", "g"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.877513236881435*^9, 3.877513249489004*^9}, {
  3.877513735601863*^9, 3.877513736016593*^9}},
 CellLabel->"In[55]:=",ExpressionUUID->"ba8ebf3e-4c40-42a9-bb50-b0509f9b3a0e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Take", "[", 
  RowBox[{"qlist", ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.8776175762375793`*^9, 3.8776175833768578`*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"ba0acab6-1f31-421f-9faa-b15fc0a03216"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "2"], ",", 
   FractionBox["3", "4"], ",", 
   RowBox[{"-", 
    FractionBox["21", "8"]}], ",", 
   FractionBox["333", "16"], ",", 
   RowBox[{"-", 
    FractionBox["30885", "128"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.877617583799326*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"d9bc2071-8f45-4fcc-88fe-8d41fa049bcf"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Large order analysis of the sequence", "Section",
 CellChangeTimes->{{3.4022248832172623`*^9, 3.402224890038163*^9}, {
  3.404128014704677*^9, 3.4041280195924387`*^9}, {3.530702576782583*^9, 
  3.530702583630056*^9}, {3.7031728813635883`*^9, 3.703172885793404*^9}, {
  3.877510855530293*^9, 3.877510859578182*^9}, {3.878204087117387*^9, 
  3.8782040964530773`*^9}},
 FontSize->36,ExpressionUUID->"4a7c0eec-1c91-44ca-8b1b-eb3f07510506"],

Cell["\<\
To do the large order analysis, we need Richardson transform of a sequence . \
The following command implements this, 
where \[OpenCurlyDoubleQuote]list\[CloseCurlyDoubleQuote] is the sequence we \
start with, and \[OpenCurlyDoubleQuote]order\[CloseCurlyDoubleQuote] is the \
order of the transform\
\>", "Text",
 CellChangeTimes->{{3.404128219025543*^9, 3.404128233779027*^9}, {
  3.7031750902539873`*^9, 3.703175091228704*^9}, {3.877934842862117*^9, 
  3.8779348897127028`*^9}, {3.877934934107234*^9, 3.877934959034687*^9}, {
  3.877963622024211*^9, 3.877963643016405*^9}, {3.87796367619352*^9, 
  3.877963706678082*^9}, {3.878204379185967*^9, 
  3.878204432600843*^9}},ExpressionUUID->"652e2606-3418-4316-8ba8-\
a05c7c89aaba"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"RichardsonTransform", "[", 
     RowBox[{"list_", ",", "0"}], "]"}], ":=", "list"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"RichardsonTransform", "[", 
      RowBox[{"list_", ",", "order_"}], "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "prev", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"prev", "=", 
         RowBox[{"RichardsonTransform", "[", 
          RowBox[{"list", ",", 
           RowBox[{"order", "-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            FractionBox["n", "order"], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"prev", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], "-", 
              RowBox[{
              "prev", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}]}], ")"}]}], "+", 
           RowBox[{
           "prev", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", 
            RowBox[{
             RowBox[{"Length", "[", "prev", "]"}], "-", "1"}]}], "}"}]}], 
         "]"}]}]}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{3.877963665416407*^9},
 CellLabel->
  "In[260]:=",ExpressionUUID->"73c062a3-6779-4bb3-8fe1-85c44570339d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extracting A", "Section",
 CellChangeTimes->{{3.844171450887299*^9, 3.844171452912423*^9}, {
  3.848641815011495*^9, 3.848641816243886*^9}, {3.849433075987344*^9, 
  3.8494330770065727`*^9}, {3.877934503568592*^9, 3.877934510746976*^9}},
 FontSize->24,ExpressionUUID->"b678563a-bf77-473e-9c34-e3425a93a247"],

Cell["\<\
Given a list \[OpenCurlyDoubleQuote]list\[CloseCurlyDoubleQuote] with the \
standard factorial large order behavior, we define an auxiliary sequence \
quot[list] which asymptotes A\
\>", "Text",
 CellChangeTimes->{{3.404128219025543*^9, 3.404128233779027*^9}, {
  3.7031750902539873`*^9, 3.703175091228704*^9}, {3.877934842862117*^9, 
  3.8779348897127028`*^9}, {3.877963528876699*^9, 
  3.877963575567865*^9}},ExpressionUUID->"358b2529-95cb-4d09-be40-\
9ac4d9cbf210"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"quot", "[", "list_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{"i", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", " ", 
        RowBox[{
         RowBox[{"Length", "[", "list", "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    RowBox[{
     RowBox[{"Delete", "[", 
      RowBox[{"list", ",", 
       RowBox[{"-", "1"}]}], "]"}], "/", 
     RowBox[{"Delete", "[", 
      RowBox[{"list", ",", "1"}], "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.877934552489251*^9, 3.877934621136895*^9}, {
  3.877934654594722*^9, 3.877934656260229*^9}},
 CellLabel->
  "In[203]:=",ExpressionUUID->"e47b30c0-1d22-406b-8dab-e5fe8d1c5d5c"],

Cell["\<\
We plot it for the first 150 coefficients of the quartic oscillator series\
\>", "Text",
 CellChangeTimes->{{3.404128219025543*^9, 3.404128233779027*^9}, {
  3.7031750902539873`*^9, 3.703175091228704*^9}, {3.877934842862117*^9, 
  3.8779349290183983`*^9}, {3.877963584515375*^9, 
  3.877963588068768*^9}},ExpressionUUID->"083f63d4-2b9c-4007-aec4-\
784cae5fcad8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"quot", "[", 
    RowBox[{"Take", "[", 
     RowBox[{"qlist", ",", "150"}], "]"}], "]"}], ",", " ", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.015", "]"}], ",", " ", "Red"}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.877934623735095*^9, 3.877934638022944*^9}, {
  3.877934671314513*^9, 3.877934680902698*^9}, {3.877935172562022*^9, 
  3.877935188795919*^9}},
 CellLabel->
  "In[211]:=",ExpressionUUID->"a57d9d89-9477-4a2c-9e1f-8bf2d55b25aa"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[1, 0, 0], PointSize[0.015], AbsoluteThickness[1.6], 
    PointBox[CompressedData["
1:eJw903tYzXcAx/GfeqZsng3VXGbJJQlZIreiT/d7Oqc63euc87gl1VqpVeSX
3E+ESjiLqFWqycPIMH4WMtoWI7alkBom9eQ2YdamT7/nnOc8r/P+fc7vn+8Z
rY6TL9QRBCGv5/3f57ur0y7g/6vVrvcLbB/n3vO6e+Yd9ZGUad4VPPNmrweh
McYqq8GwodeGqIlxsb2Wfb3Xw9DaYTnw1kp6JAoyAgvjt9AmSHC8kWFWQo9B
avehNLeT9DiUjRti3X2JHo859zfZj71OT8AzPXV3+e/0RFy+dGfKkUZ6Moyi
phk793kKoizWVVr33W8JRVK30dgb9FQc69zZtOJX2grCjufLtvxCT0O01cft
Gy7T0xHtovbS1NLWMCjVWpTV0DNQYupn8vAMPRN1cuNMxSl6Fmx2tsZ1HKdn
w1XX+p9vj9JzkB/kY1BymLbBgZL2NqmKtsWLEwaBut/Qc6HvaTcyupyeB5vs
mAfPSmk7vDSdsWrf1zSwaF71seiiXouAbJJivXwfuz2mX3IY4L+X3R4h0d3L
YwvYHeBinGdWqGV3QIBbZP6fu9gdMSZpSJjjTnZHvOh/1+zwDnYnRFWtuGCV
x+6E3MFDPzmXw+6MW2qN8cLt7M6YciL3luE2dhdMtjBPvsrzJrqguerJiIK+
8+WKTo92vcTN7K4958FQo8hid8PGNfjHUcPuhrP2g2ptNrG7o76jI2DuRnZ3
5C+dYeq2gd2j57wrjoeuZ/fAp5ljtMnr2D3xY8NolXYtuydehj8tvrCG3QsL
ms7pvcxk90Ll2lpLK1rwxsOmmrr41ezeSBl8YHN1BrsPXsROmqhLiz44Hbs0
3F9kn4/Vnnvaylexz8dFTd2G/rTgC+/61e8vTu81fFHil29dx/+r6IuIvMcN
1rTkiyfVzqeLVnAvg55pv9NGNGQ4b/S2XJPGvQyDSmPC3qMlGcrMiytWp3Iv
x7BFbxN0acjhkCNtX5/CvRwx5x63fUhLcqTumiPb9SX3fqgU7h0ZT8MPE5v2
dR1L5t4PM+I1Xe605IcWue7u5iTu/eHVXlSfTMMfk70tVg2hRX/stkrMrlrO
vT+uu8of+dBCABYuzs/oTOQ+ADWNr2xyaTEAqVkGA+bQUgBCuuxv3EngXoHa
1oN5GhoKZBvZTp9JiwpctUgruvcF9woc1BZfy6GFQCxu2fKdE41A7E8vcXoR
z30gBs5uW1JBS4GQdOqHq2ghCGaWizyH0QjCo1GmXfWfcx8EfbzR0dBSELZG
eye40EIwvLW3ZunSCMahlt/cz8ZxH4yhJ3/6SqSlYBRm7p1gTwshcPXPuqdD
IwRz34y9eD6W+xAcdXS+vJGWQlAtG9HmQwuhOKUwGmxEIxQfKdqdGmO4D8VY
E21qMS2FQp6oqIihhTBsdMupn0kjDJXT37bo9O3DkPk2vfnnZdyHwc9z8vda
WgiHpdIvOYpGOKKGxOvPosVwqGsso/X69uFQpi3dfSOa+wj8NWL0tjIaEQjb
L3qk0mIEUrY0nvWipQjcdTvYNapvHwmbipybT5ZyHwmTXO+4i7QYiT+yTh8u
oKVIvEp/sCeBFpTQSen8zIM2UcInw0A9uu/3lBCTqqa+jOq1Uoma17baK7So
hHnyfG05XajEzoG5U9bQkhKV1fWyCPq2En8rW/rNpgUVzHXP2hjSJipk30x8
3bGEz1dh07ZR9nW0UoWVOc/7H6BFFS7YOXquowtVWO6g/mABLangeP8HJwf6
tgob0tqemtCCGldLI4cLtIkaV1quVDUv5vPVmHun8+gZWqnGVh3RvJAW1TBt
kOln0IVqFO1w9VX3+F+VMB5g
     "]]}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., -0.3284848272752709},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 149.}, {-0.343606465648436, -0.3292807029791208}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.877934639799527*^9, 3.877934681580068*^9}, {
  3.877935183247311*^9, 3.877935189426969*^9}},
 CellLabel->
  "Out[211]=",ExpressionUUID->"27762a79-b844-4c28-9a27-42f540c3b06f"]
}, Open  ]],

Cell["The best approximation to A we get from the last term is ", "Text",
 CellChangeTimes->{{3.404128219025543*^9, 3.404128233779027*^9}, {
  3.7031750902539873`*^9, 3.703175091228704*^9}, {3.877934842862117*^9, 
  3.8779348897127028`*^9}, {3.877934934107234*^9, 
  3.877934959034687*^9}},ExpressionUUID->"b08cce25-c1bd-4a72-9195-\
0dc2283d6fb2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"quot", "[", 
     RowBox[{"Take", "[", 
      RowBox[{"qlist", ",", "150"}], "]"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"-", "1"}], "]"}], "]"}], ",", "15"}], "]"}]], "Input",
 CellChangeTimes->{{3.877934703333034*^9, 3.8779347304841003`*^9}, {
  3.8779349607313957`*^9, 3.877934960822481*^9}, {3.877963596916012*^9, 
  3.877963611690296*^9}},
 CellLabel->
  "In[251]:=",ExpressionUUID->"864c35fb-77ab-4566-a64a-8d6b9100ac5e"],

Cell[BoxData[
 RowBox[{"-", "0.33443506088074511043672125358592347756`15."}]], "Output",
 CellChangeTimes->{3.877963612299127*^9},
 CellLabel->
  "Out[251]=",ExpressionUUID->"ca984791-8c56-4c97-90f0-146918078c97"]
}, Open  ]],

Cell["\<\
The asymptote of this sequence to its true limit is relatively slow, in fact\
\>", "Text",
 CellChangeTimes->{{3.404128219025543*^9, 3.404128233779027*^9}, {
  3.7031750902539873`*^9, 3.703175091228704*^9}, {3.877934842862117*^9, 
  3.8779348897127028`*^9}, {3.877934934107234*^9, 3.877934959034687*^9}, {
  3.877963622024211*^9, 
  3.877963643016405*^9}},ExpressionUUID->"480bfaa0-f7c0-4aac-b96e-\
fdf31285428f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"quot", "[", 
      RowBox[{"Take", "[", 
       RowBox[{"qlist", ",", "150"}], "]"}], "]"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "/", "3"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "149"}], "}"}]}], "]"}]}], "}"}], ",", 
   " ", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.015", "]"}], ",", " ", "Red"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.01", "]"}], ",", " ", "Black"}], "}"}]}],
      "}"}]}], ",", " ", 
   RowBox[{"Joined", "->", 
    RowBox[{"{", 
     RowBox[{"False", ",", " ", "True"}], "}"}]}], ",", " ", 
   RowBox[{"PlotRange", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.343"}], ",", " ", 
      RowBox[{"-", "0.33"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.877935218390955*^9, 3.87793539422552*^9}},
 CellLabel->
  "In[222]:=",ExpressionUUID->"76a83de9-8e36-4616-ae62-5b5c779e333b"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, {}, 
     {GrayLevel[0], PointSize[0.01], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJxdzUlOVVEUheEVWzZt0KBhAwghxhAjCBaocFUsqCxAwJoHiW2nsCdh/83E
PQn7DMEhWCbmfSe5ufnOn5Uze/Zl//OFJF9/fb//f8+PjcM/5/u3fxfDpC/i
S3gKT+PLeAbP4Xm8gK/gq3gRX8PX8RJexjfwCl7FN/EtfBvfwWv4Lr6H7+N1
vIGHSRfOAzrOQzrOIzrOJh3nMR3nCR3nKR3nGR1ni46zTcfZoePs0nH26DjP
6Tgv6DgvJz3gwo3zij0u3Dj77HHhxjlgjws3zmv2uHDjHLLHhRvniD0u3DjH
7HHhxnnDHhdunLfsceHGecceF26c9+xx4cb5wB4XbpyP7HHhxvnEHhdunBP2
uHDjjCY9gwc8woXHuPE5zinv4wGPcOExbnyOc8b7eMAjXHj83z8BPzSRng==

       "]]}}, {
     {RGBColor[1, 0, 0], PointSize[0.015], AbsoluteThickness[1.6], 
      PointBox[CompressedData["
1:eJw903tYzXcAx/GfeqZsng3VXGbJJQlZIreiT/d7Oqc63euc87gl1VqpVeSX
3E+ESjiLqFWqycPIMH4WMtoWI7alkBom9eQ2YdamT7/nnOc8r/P+fc7vn+8Z
rY6TL9QRBCGv5/3f57ur0y7g/6vVrvcLbB/n3vO6e+Yd9ZGUad4VPPNmrweh
McYqq8GwodeGqIlxsb2Wfb3Xw9DaYTnw1kp6JAoyAgvjt9AmSHC8kWFWQo9B
avehNLeT9DiUjRti3X2JHo859zfZj71OT8AzPXV3+e/0RFy+dGfKkUZ6Moyi
phk793kKoizWVVr33W8JRVK30dgb9FQc69zZtOJX2grCjufLtvxCT0O01cft
Gy7T0xHtovbS1NLWMCjVWpTV0DNQYupn8vAMPRN1cuNMxSl6Fmx2tsZ1HKdn
w1XX+p9vj9JzkB/kY1BymLbBgZL2NqmKtsWLEwaBut/Qc6HvaTcyupyeB5vs
mAfPSmk7vDSdsWrf1zSwaF71seiiXouAbJJivXwfuz2mX3IY4L+X3R4h0d3L
YwvYHeBinGdWqGV3QIBbZP6fu9gdMSZpSJjjTnZHvOh/1+zwDnYnRFWtuGCV
x+6E3MFDPzmXw+6MW2qN8cLt7M6YciL3luE2dhdMtjBPvsrzJrqguerJiIK+
8+WKTo92vcTN7K4958FQo8hid8PGNfjHUcPuhrP2g2ptNrG7o76jI2DuRnZ3
5C+dYeq2gd2j57wrjoeuZ/fAp5ljtMnr2D3xY8NolXYtuydehj8tvrCG3QsL
ms7pvcxk90Ll2lpLK1rwxsOmmrr41ezeSBl8YHN1BrsPXsROmqhLiz44Hbs0
3F9kn4/Vnnvaylexz8dFTd2G/rTgC+/61e8vTu81fFHil29dx/+r6IuIvMcN
1rTkiyfVzqeLVnAvg55pv9NGNGQ4b/S2XJPGvQyDSmPC3qMlGcrMiytWp3Iv
x7BFbxN0acjhkCNtX5/CvRwx5x63fUhLcqTumiPb9SX3fqgU7h0ZT8MPE5v2
dR1L5t4PM+I1Xe605IcWue7u5iTu/eHVXlSfTMMfk70tVg2hRX/stkrMrlrO
vT+uu8of+dBCABYuzs/oTOQ+ADWNr2xyaTEAqVkGA+bQUgBCuuxv3EngXoHa
1oN5GhoKZBvZTp9JiwpctUgruvcF9woc1BZfy6GFQCxu2fKdE41A7E8vcXoR
z30gBs5uW1JBS4GQdOqHq2ghCGaWizyH0QjCo1GmXfWfcx8EfbzR0dBSELZG
eye40EIwvLW3ZunSCMahlt/cz8ZxH4yhJ3/6SqSlYBRm7p1gTwshcPXPuqdD
IwRz34y9eD6W+xAcdXS+vJGWQlAtG9HmQwuhOKUwGmxEIxQfKdqdGmO4D8VY
E21qMS2FQp6oqIihhTBsdMupn0kjDJXT37bo9O3DkPk2vfnnZdyHwc9z8vda
WgiHpdIvOYpGOKKGxOvPosVwqGsso/X69uFQpi3dfSOa+wj8NWL0tjIaEQjb
L3qk0mIEUrY0nvWipQjcdTvYNapvHwmbipybT5ZyHwmTXO+4i7QYiT+yTh8u
oKVIvEp/sCeBFpTQSen8zIM2UcInw0A9uu/3lBCTqqa+jOq1Uoma17baK7So
hHnyfG05XajEzoG5U9bQkhKV1fWyCPq2En8rW/rNpgUVzHXP2hjSJipk30x8
3bGEz1dh07ZR9nW0UoWVOc/7H6BFFS7YOXquowtVWO6g/mABLangeP8HJwf6
tgob0tqemtCCGldLI4cLtIkaV1quVDUv5vPVmHun8+gZWqnGVh3RvJAW1TBt
kOln0IVqFO1w9VX3+F+VMB5g
       "]]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., -0.33000000000000074`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 149.}, {-0.343, -0.33}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8779352647764673`*^9, {3.87793530939996*^9, 3.877935395060726*^9}},
 CellLabel->
  "Out[222]=",ExpressionUUID->"87c64b15-2169-43f8-860a-ccb102c19fab"]
}, Open  ]],

Cell["\<\
We can see that already the first Richardson transform of the quot sequence \
asymptotes much faster to the expected value -1/3\
\>", "Text",
 CellChangeTimes->{{3.404128219025543*^9, 3.404128233779027*^9}, {
  3.7031750902539873`*^9, 3.703175091228704*^9}, {3.877934842862117*^9, 
  3.8779348897127028`*^9}, {3.877934934107234*^9, 3.877934959034687*^9}, {
  3.877963622024211*^9, 3.877963643016405*^9}, {3.87796367619352*^9, 
  3.877963740430154*^9}},ExpressionUUID->"fc3036c4-2a97-42d2-a8cd-\
8704ba5c40e0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"quot", "[", 
      RowBox[{"Take", "[", 
       RowBox[{"qlist", ",", "150"}], "]"}], "]"}], ",", 
     RowBox[{"RichardsonTransform", "[", 
      RowBox[{
       RowBox[{"quot", "[", 
        RowBox[{"Take", "[", 
         RowBox[{"qlist", ",", "150"}], "]"}], "]"}], ",", " ", "1"}], "]"}], 
     ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "/", "3"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "149"}], "}"}]}], "]"}]}], "}"}], ",", 
   " ", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.015", "]"}], ",", " ", "Red"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.01", "]"}], ",", " ", "Blue"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.01", "]"}], ",", " ", "Black"}], "}"}]}],
      "}"}]}], ",", " ", 
   RowBox[{"Joined", "->", 
    RowBox[{"{", 
     RowBox[{"False", ",", "False", ",", "  ", "True"}], "}"}]}]}], 
  RowBox[{"(*", 
   RowBox[{",", " ", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.343"}], ",", " ", 
       RowBox[{"-", "0.33"}]}], "}"}]}]}], "*)"}], "]"}]], "Input",
 CellChangeTimes->{{3.877935218390955*^9, 3.87793539422552*^9}, {
  3.877962143077949*^9, 3.877962184517818*^9}, {3.87796231769341*^9, 
  3.877962326905306*^9}},
 CellLabel->
  "In[249]:=",ExpressionUUID->"2658b1c3-28a5-49f3-823a-507df62d9321"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, {}, {}, 
     {GrayLevel[0], PointSize[0.01], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJxdzUlOVVEUheEVWzZt0KBhAwghxhAjCBaocFUsqCxAwJoHiW2nsCdh/83E
PQn7DMEhWCbmfSe5ufnOn5Uze/Zl//OFJF9/fb//f8+PjcM/5/u3fxfDpC/i
S3gKT+PLeAbP4Xm8gK/gq3gRX8PX8RJexjfwCl7FN/EtfBvfwWv4Lr6H7+N1
vIGHSRfOAzrOQzrOIzrOJh3nMR3nCR3nKR3nGR1ni46zTcfZoePs0nH26DjP
6Tgv6DgvJz3gwo3zij0u3Dj77HHhxjlgjws3zmv2uHDjHLLHhRvniD0u3DjH
7HHhxnnDHhdunLfsceHGecceF26c9+xx4cb5wB4XbpyP7HHhxvnEHhdunBP2
uHDjjCY9gwc8woXHuPE5zinv4wGPcOExbnyOc8b7eMAjXHj83z8BPzSRng==

       "]]}}, {
     {RGBColor[1, 0, 0], PointSize[0.015], AbsoluteThickness[1.6], 
      PointBox[CompressedData["
1:eJw903tYzXcAx/GfeqZsng3VXGbJJQlZIreiT/d7Oqc63euc87gl1VqpVeSX
3E+ESjiLqFWqycPIMH4WMtoWI7alkBom9eQ2YdamT7/nnOc8r/P+fc7vn+8Z
rY6TL9QRBCGv5/3f57ur0y7g/6vVrvcLbB/n3vO6e+Yd9ZGUad4VPPNmrweh
McYqq8GwodeGqIlxsb2Wfb3Xw9DaYTnw1kp6JAoyAgvjt9AmSHC8kWFWQo9B
avehNLeT9DiUjRti3X2JHo859zfZj71OT8AzPXV3+e/0RFy+dGfKkUZ6Moyi
phk793kKoizWVVr33W8JRVK30dgb9FQc69zZtOJX2grCjufLtvxCT0O01cft
Gy7T0xHtovbS1NLWMCjVWpTV0DNQYupn8vAMPRN1cuNMxSl6Fmx2tsZ1HKdn
w1XX+p9vj9JzkB/kY1BymLbBgZL2NqmKtsWLEwaBut/Qc6HvaTcyupyeB5vs
mAfPSmk7vDSdsWrf1zSwaF71seiiXouAbJJivXwfuz2mX3IY4L+X3R4h0d3L
YwvYHeBinGdWqGV3QIBbZP6fu9gdMSZpSJjjTnZHvOh/1+zwDnYnRFWtuGCV
x+6E3MFDPzmXw+6MW2qN8cLt7M6YciL3luE2dhdMtjBPvsrzJrqguerJiIK+
8+WKTo92vcTN7K4958FQo8hid8PGNfjHUcPuhrP2g2ptNrG7o76jI2DuRnZ3
5C+dYeq2gd2j57wrjoeuZ/fAp5ljtMnr2D3xY8NolXYtuydehj8tvrCG3QsL
ms7pvcxk90Ll2lpLK1rwxsOmmrr41ezeSBl8YHN1BrsPXsROmqhLiz44Hbs0
3F9kn4/Vnnvaylexz8dFTd2G/rTgC+/61e8vTu81fFHil29dx/+r6IuIvMcN
1rTkiyfVzqeLVnAvg55pv9NGNGQ4b/S2XJPGvQyDSmPC3qMlGcrMiytWp3Iv
x7BFbxN0acjhkCNtX5/CvRwx5x63fUhLcqTumiPb9SX3fqgU7h0ZT8MPE5v2
dR1L5t4PM+I1Xe605IcWue7u5iTu/eHVXlSfTMMfk70tVg2hRX/stkrMrlrO
vT+uu8of+dBCABYuzs/oTOQ+ADWNr2xyaTEAqVkGA+bQUgBCuuxv3EngXoHa
1oN5GhoKZBvZTp9JiwpctUgruvcF9woc1BZfy6GFQCxu2fKdE41A7E8vcXoR
z30gBs5uW1JBS4GQdOqHq2ghCGaWizyH0QjCo1GmXfWfcx8EfbzR0dBSELZG
eye40EIwvLW3ZunSCMahlt/cz8ZxH4yhJ3/6SqSlYBRm7p1gTwshcPXPuqdD
IwRz34y9eD6W+xAcdXS+vJGWQlAtG9HmQwuhOKUwGmxEIxQfKdqdGmO4D8VY
E21qMS2FQp6oqIihhTBsdMupn0kjDJXT37bo9O3DkPk2vfnnZdyHwc9z8vda
WgiHpdIvOYpGOKKGxOvPosVwqGsso/X69uFQpi3dfSOa+wj8NWL0tjIaEQjb
L3qk0mIEUrY0nvWipQjcdTvYNapvHwmbipybT5ZyHwmTXO+4i7QYiT+yTh8u
oKVIvEp/sCeBFpTQSen8zIM2UcInw0A9uu/3lBCTqqa+jOq1Uoma17baK7So
hHnyfG05XajEzoG5U9bQkhKV1fWyCPq2En8rW/rNpgUVzHXP2hjSJipk30x8
3bGEz1dh07ZR9nW0UoWVOc/7H6BFFS7YOXquowtVWO6g/mABLangeP8HJwf6
tgob0tqemtCCGldLI4cLtIkaV1quVDUv5vPVmHun8+gZWqnGVh3RvJAW1TBt
kOln0IVqFO1w9VX3+F+VMB5g
       "]]}, 
     {RGBColor[0, 0, 1], PointSize[0.01], AbsoluteThickness[1.6], 
      PointBox[CompressedData["
1:eJw9zQ001Xccx/G76VoqxdpQjDLriVJRHqb5KM/Jw3Wf3Af3IZZqUScPSerW
tJod25iiU4SkMSkNU84QLVGSiiQtpO4Sk6mT2mTtzO97z73nnvf93Nf/O1cd
xQt/l8PhpL/9/Pf9/+uZa5qVz9t3b83ED0hJ2LunrbJhoiejcLV7bUtL60Qb
IG7LPr9mzu2J/gBRo51rOSvbJtoEyyQm+8U9rM0Qc72taZN9+0TPwZm/8wNt
A1hbwijWlHPQm7UVpFcaS9OXsp4Hd4/G5aOGrBdgbKFiq/4Ie/4iHLqtKzS7
w9oGOZ9cePxFDesl8Nsu7DQvZr0UcrPe4zXHWC9DRv8N3qnvWS9H+iHbKOsD
rO0QXlI1Xr6HtT2+unW/71o86xVYqFdoZBjDeiUe6zZmOW9j7YDm77iNMyNZ
O0KQK2qI3szaCfriEn1sZO2MSM9dqYoNrD/Fi6bhC3XhrF1wZdcdrSyM9Src
nZQosVrP+jOEOw3FGqpZu8LBtMPBXMUauHkvvclDOdEaILGg3TNJwXY3uC8r
iG8PZbsbMnrmVDux5qzGjsk63T/J2b4aPY/dudasOWtQ/aLnWLmM7WsQenZb
kC9rjjuMdY+90UrZ7g4vo8ofU1hzPGBdMTPWmXYPaKckFQ5K2O6JpydeZhWw
1niiZfhWXRjtXigpf545n3YvRGxffPbPELZ7Q3/c7uR51hpvpKV1Wxyk3Qdn
+39uDaHdB1umZUQvod0XY/VNjVzafVHT9ibzgZjta/FEknymirVmLbqf1zw4
QrsfVsSGcHbS7gdZ2MunUtrXQRZcqnGlfR32ZZUdt6LdH5WqIZuptPvDX+/y
9BER2wOQ19W6uIu1JgDREaeiL9MeiE0FJ1pKWSMQIp0am2z6fyB694QnfMO6
NhDO7sHF8eSDsNU4pjSCfBCmu15LFJMPQppMwPUhH4SOgWEXZ/I8lM3iz7Yh
z0NW5sAP5uR5MJZ05hiS54Hfds+RSz4YxnVu/FdC5oNxxOTh00HWmmCY2L//
qpd1bTB0XqXFdLDm8CF7mCq9Tp4Py0dHT14iz0f8+GH/KvJ87P+yKugceQG8
+lOKCskLcMD+Lj+XvAC7fyv0O0JegLhi729TyQvRwHMwSiYvRFWSdc8+8kKM
Xps6kEBeiNrZA3Yx5EUIKJ5SEUleBDuH5qgI8iJ86FMdqiYvwpSuZI2MvBiD
szi3hOTFKPPV4weRF2Nu/+l3/MiLEdczo9OTfAicejfecyMfApcH+pNWkQ9B
au56niP5EHDjtJfsyEuwZHSBxJa8BPZ9jQbW5CVINkjUziMvgeVm7n1L8lIU
6694Zk5eir3KAQtT8lIs9Zu12Zi8FNt3VNyYSV6GvIymAAPyMpz7dYN2GnkZ
hi8WHdYjL8PpogsyXfJyfGx5xVGHvByjI9MWccjLUZ521XZMwLwcFfn+Pq9Z
c0LxOuOPmJesEYool5Gy56w1oVgV1sL9i3woSr7u2zBEXoHgnTmdA+QV0H8v
Tt5PXoHCyp4hLXkF6g4qUh+RVyIvO9rtIes5SvTNKBrvpucpkZGfcvV31kol
irJL87vo+UpEJhUnd7LOUWJs0CSxg+4pIRQcSmhn3a3E5Cf1+2/TfRXcVL5H
b9J9FT6601p1g+6rYJStq71O91XYYpFp1kz3Vdjxi6PsKt1XoSw962Qj3Vdh
V+bu0Qa6r4LI6TD/Mt1Xo/7z3POX6L4akkjF/Hq6r4aoNzXrIt1Xw3/vP6a1
dF8NI4vwvOq3/S+ImBmv
       "]]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., -0.329079877585619},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 149.}, {-0.3395077045800168, -0.3296287105853233}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.8779621566358013`*^9, 3.877962185399282*^9}, 
   3.877963375658601*^9},
 CellLabel->
  "Out[249]=",ExpressionUUID->"8da80739-469f-4729-b78d-7ba56d6d41d1"]
}, Open  ]],

Cell["\<\
The best approximation to A we get from the first Richardson transform is \
already an important improvement on the naive extrapolation\
\>", "Text",
 CellChangeTimes->{{3.404128219025543*^9, 3.404128233779027*^9}, {
  3.7031750902539873`*^9, 3.703175091228704*^9}, {3.877934842862117*^9, 
  3.8779348897127028`*^9}, {3.877934934107234*^9, 3.877934959034687*^9}, {
  3.8779622037648973`*^9, 3.877962208393756*^9}, {3.8779637475006857`*^9, 
  3.877963771698166*^9}},ExpressionUUID->"c47d972e-a5bc-4202-a9e7-\
ef7f019a46a0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{"RichardsonTransform", "[", 
      RowBox[{
       RowBox[{"quot", "[", 
        RowBox[{"Take", "[", 
         RowBox[{"qlist", ",", "150"}], "]"}], "]"}], ",", " ", "1"}], "]"}], 
     ",", 
     RowBox[{"-", "1"}]}], "]"}], ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.877934703333034*^9, 3.8779347304841003`*^9}, {
  3.8779349607313957`*^9, 3.877934960822481*^9}, {3.877962217748898*^9, 
  3.8779622212217607`*^9}},
 CellLabel->
  "In[229]:=",ExpressionUUID->"a0852e17-4f22-4ade-9ce9-08b12f6d8636"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", "0.33335843905341401719972455515218261632`10."}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.8779347263468037`*^9, 3.877934731295343*^9}, 
   3.877934961630396*^9, 3.8779622218825617`*^9},
 CellLabel->
  "Out[229]=",ExpressionUUID->"a7da1b7a-b2a7-4910-8e0f-d6b8ff562ec3"]
}, Open  ]],

Cell["\<\
The best approximation to A we get from the fitht Richardson transform is \
even better.\
\>", "Text",
 CellChangeTimes->{{3.404128219025543*^9, 3.404128233779027*^9}, {
  3.7031750902539873`*^9, 3.703175091228704*^9}, {3.877934842862117*^9, 
  3.8779348897127028`*^9}, {3.877934934107234*^9, 3.877934959034687*^9}, {
  3.8779622037648973`*^9, 3.877962208393756*^9}, {3.877962286540909*^9, 
  3.877962290323731*^9}, {3.8779637734399433`*^9, 
  3.8779637758136253`*^9}},ExpressionUUID->"939b9383-d365-4db8-aece-\
4c3c1cfc8cd6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"RichardsonTransform", "[", 
     RowBox[{
      RowBox[{"quot", "[", 
       RowBox[{"Take", "[", 
        RowBox[{"qlist", ",", "150"}], "]"}], "]"}], ",", " ", "5"}], "]"}], 
    "[", 
    RowBox[{"[", 
     RowBox[{"-", "1"}], "]"}], "]"}], ",", "20"}], "]"}]], "Input",
 CellChangeTimes->{{3.877934703333034*^9, 3.8779347304841003`*^9}, {
  3.8779349607313957`*^9, 3.877934960822481*^9}, {3.877962217748898*^9, 
  3.877962236464628*^9}, {3.877962752592523*^9, 3.877962758510206*^9}},
 CellLabel->
  "In[245]:=",ExpressionUUID->"71e9ff02-fe95-46b3-abd0-b962d1a523bf"],

Cell[BoxData[
 RowBox[{"-", "0.33333333336130551778837425088239282686`20."}]], "Output",
 CellChangeTimes->{{3.8779347263468037`*^9, 3.877934731295343*^9}, 
   3.877934961630396*^9, {3.8779622218825617`*^9, 3.877962237159915*^9}, 
   3.877962759440812*^9},
 CellLabel->
  "Out[245]=",ExpressionUUID->"06a5b1b7-4314-477f-b655-a1cc690fea7c"]
}, Open  ]],

Cell["\<\
By increasing the order of the Richardson transform, we can get the value \
-1/3 with 22 digits. This is the maximum that we can obtain with 150 terms\
\>", "Text",
 CellChangeTimes->{{3.404128219025543*^9, 3.404128233779027*^9}, {
  3.7031750902539873`*^9, 3.703175091228704*^9}, {3.877934842862117*^9, 
  3.8779348897127028`*^9}, {3.877934934107234*^9, 3.877934959034687*^9}, {
  3.8779622037648973`*^9, 3.877962208393756*^9}, {3.877962286540909*^9, 
  3.877962290323731*^9}, {3.877962503627467*^9, 3.877962517620816*^9}, {
  3.8779626900681334`*^9, 
  3.877962743729858*^9}},ExpressionUUID->"3f05cd8e-c09c-444b-bf09-\
d32f27ee4224"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"RichardsonTransform", "[", 
      RowBox[{
       RowBox[{"quot", "[", 
        RowBox[{"Take", "[", 
         RowBox[{"qlist", ",", "150"}], "]"}], "]"}], ",", " ", "35"}], "]"}],
      "[", 
     RowBox[{"[", 
      RowBox[{"-", "1"}], "]"}], "]"}], ",", "50"}], "]"}], "+", 
  RowBox[{"1", "/", "3"}]}]], "Input",
 CellChangeTimes->{{3.877934703333034*^9, 3.8779347304841003`*^9}, {
  3.8779349607313957`*^9, 3.877934960822481*^9}, {3.877962217748898*^9, 
  3.877962236464628*^9}, {3.877962460111268*^9, 3.8779624917671957`*^9}, {
  3.877962524282936*^9, 3.87796261650403*^9}, {3.877962766221425*^9, 
  3.877962779627782*^9}},
 CellLabel->
  "In[248]:=",ExpressionUUID->"ce82c896-2810-4f0e-8f66-905c888c7561"],

Cell[BoxData[
 RowBox[{"-", 
  "7.088244910924089855836268348590706021475705838373366218`28.\
327659969471306*^-23"}]], "Output",
 CellChangeTimes->{{3.877962772305111*^9, 3.8779627818540382`*^9}},
 CellLabel->
  "Out[248]=",ExpressionUUID->"faf0f204-d4b8-42d1-bf85-3e911922fe7d"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extracting b", "Section",
 CellChangeTimes->{{3.844171450887299*^9, 3.844171452912423*^9}, {
  3.848641815011495*^9, 3.848641816243886*^9}, {3.849433075987344*^9, 
  3.8494330770065727`*^9}, {3.877934503568592*^9, 3.877934510746976*^9}, {
  3.878204221851781*^9, 3.8782042230113983`*^9}},
 FontSize->24,ExpressionUUID->"c0ba25b5-a58c-48a2-abe0-da62b4700d91"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"bseq", "[", "list_", "]"}], ":=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", " ", 
         RowBox[{
          RowBox[{"Length", "[", "list", "]"}], "-", "2"}]}], "}"}]}], 
      "]"}]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], "i"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", " ", 
           RowBox[{
            RowBox[{"Length", "[", "list", "]"}], "-", "2"}]}], "}"}]}], 
        "]"}], 
       RowBox[{
        RowBox[{"Delete", "[", 
         RowBox[{"list", ",", 
          RowBox[{"-", "1"}]}], "]"}], "/", 
        RowBox[{"Delete", "[", 
         RowBox[{"list", ",", "1"}], "]"}]}]}], "-", 
      RowBox[{"Table", "[", 
       RowBox[{"1", ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", " ", 
          RowBox[{
           RowBox[{"Length", "[", "list", "]"}], "-", "1"}]}], "}"}]}], 
       "]"}]}], ")"}]}]}], " ", ";"}]], "Input",
 CellChangeTimes->{{3.878009220390716*^9, 3.878009289326207*^9}, {
  3.878009479112906*^9, 3.878009479606001*^9}, {3.878009569436819*^9, 
  3.878009590906801*^9}, {3.878009623020187*^9, 3.878009643954591*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"f770ab96-4a7e-4669-a1af-fdb8ec982cb0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"bseq", "[", 
   RowBox[{"Take", "[", 
    RowBox[{"qlist", ",", " ", "150"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.878009304324874*^9, 3.878009339539597*^9}, 
   3.8780094838230886`*^9},
 CellLabel->"In[28]:=",ExpressionUUID->"4ba294b7-6139-4faf-90b9-fb1b7aeeefc8"],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVzXk41Akcx3EdjNruVIpKImeSbDOU8XE0GOOaGcxlzEzpWMq2KG2lqcez
le1QClkqXTpkabctj6yhtnsaWZK0YrNCz+ogHTq2ffb3/WN/z8wzz3s+v9fz
naFJFMYNNjIy2v/5++/vf89zb6P/P9hrE/T5U8P8bwrHl1J2rvUjpsfAQ9/Q
cWbdX0ybQWLTNrZO28m0OU7Y3EmSne1i2hKZvYpK2/PUVhD7T2SlTKa2BjJf
zQ53I2+DYQ4friWwnzA9C0UTykQbAjuYtsepgFd9x5PpviPGJmftPatrZ9oZ
6YsT52Q4UbtgXrkoZ2PZY6Zd8diwpLM3hHouZNLNL7e8/5NpN7BHpXZLy6nn
QT/EfUTsZmp3NMyz2GQjpP4SIzeNctM7UM/H6LmiWz0m1GyoqzIL1nS2Mc3B
fZMV+Vl6ag+0d5cojp+n9sQNLI+bc5h6AUrZqR2GHdQLwc/rGOCsp/ZCUpqt
3imemgtzj75BKQpqb9iqcx27Q6kBx9UeDct8mdYCvU2t02rn0+6Dn+/HFwxz
pt0HjbcsMj7OoN0Xu6uPWeSb0+6Ltrh9Q+pG0+6HkosxJntZtPtBebGiyPCp
ldn90bH2VsemN0xr/bH2l1UmB17QvgijZ2pixz2lfREsU8Z4trfTzsO2xYdK
WI9o5yF627CMNU20B8CsWcJ2qqc9AKZpvGIrA+2BaPI9LRHepD0Ql9b5mF/6
jfYgLEyMnyWrpj0IY95+P96hknY+XlbUVdiW087HB5+53iHnaQ+Gj7PoXX4Z
7cHw5CZpx5XQLoBgfM/+M6dpF+AOL9VpaRHtIWj8u02KY7SHYPZRsZJTSHso
rN3fZwsO0h6KXtEI7fofaA9DWumkssu5tIdhxPKSBzOzaQ/HWL8FV/KymEY4
HsKcb7eH3g+HvXG9/PoupnXhEO088m7DDvIRWBnSx/bPIB+B8qQ57lO3kY9A
2YGtU1nfkY/AuYPPXQalkxeiWe/w4/At5IWYfb3lmbWWvBBvXzcLgtLIC3F3
n9hp4wbyIuSlct5WfktehKucXOcv1pEXocB6ot+SteRFmNaqqb6eQl6MxuIr
bpxk8mJ0TT9pf+4b8mKUnfbwnL+avBiGwayhVxLJR+JBTZGdfBX5SNgdSgge
SCAfCXm+2ZRj8eQjcefyVt/Ir8hHIbMle+2oFeSjEHWrKtGwjHwUakf2t+cs
JR+F59zEfcviyEejd2QSl7uEfDT4211OWCwmHw2TlRl7PqnJR2ON59AbXSry
Ejxs2z7pQSx5CYbfjubXKslL8GxCk+vtGPISzKvfnq9XkJdCymlW1cvJS8FL
nixqlZGX4o8FIv4LKXkphlzznc6iNpJBz+EUz5CQl6FRaKxHNHkZCmK6lUui
yMtw0jUdOyLJy9HNq4i4KCYvh5f+p6ROEXk5AvN+3WZJrZNDZRScLBaSV2BS
fNOUzAjyCgRU9KgN4eQViIo0dR1HrVNAdC8zQRJGPgYr4xo+FYaSj8GLnIG6
nhDyMahpeW3gUutiUJuc3rZHQF6J8qvmvU+CySvBEbQ9B7VWiSO3L1zL55NX
wtjUMm4giHwsWFXOFxTUiEX/+MJiXSD5WDz1rnG3o9bFwjInzjszgLwKTxo7
Lg3wmLZSQa6zPriCGioEdayub1rEtEoFpztHIwTUWhW+9nrHqvZn+rAKj6/Y
dLOpdSo4ahc+LfVjulWFjSzdRydqIzW6Mnebn/Kl+2pkcbuc7amhRmFOnOsp
H7qvRrZD3yRnaq0a/WH375eC7qvBtzqxnE2tU+NIqndllTfdV+N3l7u3g6iN
NDAoa3c2cOm+Blvvve7XUEODloJFn1540X0NxAfeFGyh1mpgzNt104z68Of3
d+o2nFzY6v0Pn+jSBQ==
      "]]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 149.}, {0, 0.5931290197126731}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.878009316675379*^9, 3.878009330739336*^9}, 
   3.8780094843290586`*^9, 3.8780096464407187`*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"90b5bcc8-4110-4df6-aa7b-8a7b4a0a8e3b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"bseq", "[", 
      RowBox[{"Take", "[", 
       RowBox[{"qlist", ",", " ", "150"}], "]"}], "]"}], ",", 
     RowBox[{"RichardsonTransform", "[", 
      RowBox[{
       RowBox[{"bseq", "[", 
        RowBox[{"Take", "[", 
         RowBox[{"qlist", ",", " ", "150"}], "]"}], "]"}], ",", " ", "1"}], 
      "]"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"1", "/", "2"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "149"}], "}"}]}], "]"}]}], "}"}], ",", 
   " ", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.015", "]"}], ",", " ", "Red"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.01", "]"}], ",", " ", "Blue"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.01", "]"}], ",", " ", "Black"}], "}"}]}],
      "}"}]}], ",", " ", 
   RowBox[{"Joined", "->", 
    RowBox[{"{", 
     RowBox[{"False", ",", "False", ",", "  ", "True"}], "}"}]}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.878009370610971*^9, 3.8780094118743343`*^9}, 
   3.8780094908217382`*^9, {3.878009658491644*^9, 3.878009672482004*^9}, {
   3.878009705931061*^9, 3.878009708745371*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"fc025a79-b317-4a45-baf9-34d0b4aafb4b"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, {}, {}, 
     {GrayLevel[0], PointSize[0.01], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJxdzctKlXEUxuGXRg0dNHDQQENCIqQytbNfR7U8a+eDW8Gxt7Buovm+lHUp
+xK6hAqD2M8HH4uHHy//+bOLw/MrSX7++f/ey+/X+uWd/LsZpn0Vz+BreBZf
x3P4Bl7AN/EivoVv4yV8B9/F9/Ayvo9X8Cpeww/wQ/wIP8ZP8FP8DK/jYdqF
85yO84KO85KO84qO85qO84aOs0HH2aTjbNFx3tJx3tFxtuk4O3ScXTrOHh1n
f9oDLtw4B+xx4cY5ZI8LN84Re1y4cY7Z48KN8549Ltw4H9jjwo3zkT0u3Dif
2OPCjfOZPS7cOF/Y48KN85U9Ltw439jjwo3znT0u3Dg/2OPCjXPCHhdunNG0
5/CAR7jwGDee4JzyPh7wCBce48YTnDPexwMe4cLj//4NbDgkoA==
       "]]}}, {
     {RGBColor[1, 0, 0], PointSize[0.015], AbsoluteThickness[1.6], 
      PointBox[CompressedData["
1:eJxVzXk41Akcx3EdjNruVIpKImeSbDOU8XE0GOOaGcxlzEzpWMq2KG2lqcez
le1QClkqXTpkabctj6yhtnsaWZK0YrNCz+ogHTq2ffb3/WN/z8wzz3s+v9fz
naFJFMYNNjIy2v/5++/vf89zb6P/P9hrE/T5U8P8bwrHl1J2rvUjpsfAQ9/Q
cWbdX0ybQWLTNrZO28m0OU7Y3EmSne1i2hKZvYpK2/PUVhD7T2SlTKa2BjJf
zQ53I2+DYQ4friWwnzA9C0UTykQbAjuYtsepgFd9x5PpviPGJmftPatrZ9oZ
6YsT52Q4UbtgXrkoZ2PZY6Zd8diwpLM3hHouZNLNL7e8/5NpN7BHpXZLy6nn
QT/EfUTsZmp3NMyz2GQjpP4SIzeNctM7UM/H6LmiWz0m1GyoqzIL1nS2Mc3B
fZMV+Vl6ag+0d5cojp+n9sQNLI+bc5h6AUrZqR2GHdQLwc/rGOCsp/ZCUpqt
3imemgtzj75BKQpqb9iqcx27Q6kBx9UeDct8mdYCvU2t02rn0+6Dn+/HFwxz
pt0HjbcsMj7OoN0Xu6uPWeSb0+6Ltrh9Q+pG0+6HkosxJntZtPtBebGiyPCp
ldn90bH2VsemN0xr/bH2l1UmB17QvgijZ2pixz2lfREsU8Z4trfTzsO2xYdK
WI9o5yF627CMNU20B8CsWcJ2qqc9AKZpvGIrA+2BaPI9LRHepD0Ql9b5mF/6
jfYgLEyMnyWrpj0IY95+P96hknY+XlbUVdiW087HB5+53iHnaQ+Gj7PoXX4Z
7cHw5CZpx5XQLoBgfM/+M6dpF+AOL9VpaRHtIWj8u02KY7SHYPZRsZJTSHso
rN3fZwsO0h6KXtEI7fofaA9DWumkssu5tIdhxPKSBzOzaQ/HWL8FV/KymEY4
HsKcb7eH3g+HvXG9/PoupnXhEO088m7DDvIRWBnSx/bPIB+B8qQ57lO3kY9A
2YGtU1nfkY/AuYPPXQalkxeiWe/w4/At5IWYfb3lmbWWvBBvXzcLgtLIC3F3
n9hp4wbyIuSlct5WfktehKucXOcv1pEXocB6ot+SteRFmNaqqb6eQl6MxuIr
bpxk8mJ0TT9pf+4b8mKUnfbwnL+avBiGwayhVxLJR+JBTZGdfBX5SNgdSgge
SCAfCXm+2ZRj8eQjcefyVt/Ir8hHIbMle+2oFeSjEHWrKtGwjHwUakf2t+cs
JR+F59zEfcviyEejd2QSl7uEfDT4211OWCwmHw2TlRl7PqnJR2ON59AbXSry
Ejxs2z7pQSx5CYbfjubXKslL8GxCk+vtGPISzKvfnq9XkJdCymlW1cvJS8FL
nixqlZGX4o8FIv4LKXkphlzznc6iNpJBz+EUz5CQl6FRaKxHNHkZCmK6lUui
yMtw0jUdOyLJy9HNq4i4KCYvh5f+p6ROEXk5AvN+3WZJrZNDZRScLBaSV2BS
fNOUzAjyCgRU9KgN4eQViIo0dR1HrVNAdC8zQRJGPgYr4xo+FYaSj8GLnIG6
nhDyMahpeW3gUutiUJuc3rZHQF6J8qvmvU+CySvBEbQ9B7VWiSO3L1zL55NX
wtjUMm4giHwsWFXOFxTUiEX/+MJiXSD5WDz1rnG3o9bFwjInzjszgLwKTxo7
Lg3wmLZSQa6zPriCGioEdayub1rEtEoFpztHIwTUWhW+9nrHqvZn+rAKj6/Y
dLOpdSo4ahc+LfVjulWFjSzdRydqIzW6Mnebn/Kl+2pkcbuc7amhRmFOnOsp
H7qvRrZD3yRnaq0a/WH375eC7qvBtzqxnE2tU+NIqndllTfdV+N3l7u3g6iN
NDAoa3c2cOm+Blvvve7XUEODloJFn1540X0NxAfeFGyh1mpgzNt104z68Of3
d+o2nFzY6v0Pn+jSBQ==
       "]]}, 
     {RGBColor[0, 0, 1], PointSize[0.01], AbsoluteThickness[1.6], 
      PointBox[CompressedData["
1:eJw9zg841Accx/FfmmRmJLVKGpckm5KG0crHf5dwDsedf3dXqa2kh0zPQlcq
I5uQptj6Y0pZJcrfp3b6M5VCNkUREy1x/hVJYu3ZfX+eu+ee133u/fsylEbw
N6gwDHPo/fu/z///BuzSjbjvX9fslF9A9Uy1jtfBF0pPR1VFxlXLvAGltfH4
0G4up4asi9ZFe97uDO1Teg4MJ4zNFrR0Kz0fCpOtVbyoLqUNUJyrvdqz/W+l
Och7EmWeK3+itBHW107/TvvGY6WNkRCzOiEl6JHSJvig/GqhyodkUzTZxM28
Hkj+HGbGTZXF78hLoaOXf76pjJ5njsxake7t8Ball2N62R9/pmu2Km2BE3kh
GVsyyCtQYlJurMnQ//cFNpnYvvpVQLZEtIU0ST+bbAXnJttyy/tkaywRTKgu
HCd/iaG6XuedC9qUtkF8zsFw2JJtEZ3/scobHnklrq+04d9ZR/4KF/VTr6RG
kVfB1sUwTSEjr4Z7oyQ5NIVsh9hci3zHw2QgU9dDt+MXpWVAquSn1shTtNuj
1OXQXM452u3xovpsm04x7Q4QVFyIlJTR7gCdSlGj0RXaHREtzH0VUUW7I4zu
Ou7n36TdCXZxRwubb9HuhK2WD5K179LujGyL17uYOtqdEa2yKOfifdpdYLG1
8rbpX7S7YPnikSmRD2h3xWXnOdtTmmh3RTmW5cU/ot0NM/TUk9e20O6GvX3p
OW9aaeei91KK4vs22rlIyOKueNdO+xro9Go8COigfQ0Ee8PHfn5KuztOKsyS
aztpd0ev+vmVvV20r0XaBX7W6DPa1+J6//iU4X9o98DpaVdLO57T7oGJ2c+a
r3XT7ol9/MTwwy9o98R41Z7QkB7avVDENU/U66XdC9E5hfm1ZIaHwc3D3+5Q
KA0e1M2TM+f20e95qIHx0SKynAdOvtbHTv3UeyPkpW9ELRneGAl5upw/QL03
Wvrj5HVkuTeCwo7EuQ5Sz4fsa4Mb5WTwUdfAeW48RD0fXTmR1qlkOR8FJ8zH
hsiMD3ga7lH8l9T7IH9+f/s5sswHBb/3x6q+ot4HhfM4cUIy4wt954szz5Lh
i+EZ30S8Jst80XdrstJ+mHpftKas4SSRGT+8+0R26x4ZfmiVbmzQGqHeD0xF
osSLLPeDWqlPZgqZEWDHPt6BajIEyKyzCWVeUy9ATR7nM2uyXAC7sxlqW8iM
P8TXTmkcI8MfgiQDj3q294dRWWL7JNv7o6fIttlslPoANG1I4IrICMCyrDMO
+8iyAAw8nNp4niwPgJO+mvZDthdCYe+nMsH2QuiE3Slf+IZ6IbKFSY5uZLkQ
bQvUfttMZkQoOTJr8gcyRNCNVbheYHsRundZp9WxvQjbxnW7+tg+EKqdiz00
x6gPhLXV0QZTsiwQHw0axbuS5YGwPTA7YB2ZCcJ6Rrgpnu2DUBATU5LF9kGY
nZLLLWL7INSvqjCpYftgHEx3Ez1l+2Bo9qR2jrF9MFp1ku/NeEt9MIq1FPNM
yEwIdl9a2rCKjBDcHE8c5ZNlIaheMZq+ke1DENHjemon24ei/6aGdSrbh0I0
6zT3JNuHYsDHs+MS24eiMkZdtZrtxRhcWHK5iWwghmuF+mg3+zwxfD0z6sbI
YjEUsVfsNMbp+WI4LKl31yMfF2O94dCIKVkuhrzA1MmW3C7G5ITUiktmJMjO
21jvTzaQYFttt24YGRKEHZBN204WS8CfPHN6N3tfAo3Yu2M/svclOJ5mrZLD
3pcgS2uRPJ+9LwHzptzqMntfik+3qG2qYu9LER6vIbjH3pciU7NIpZm9L8XU
/Y0Rnex9KUqP2R3rf+9/AeqwC9Q=
       "]]}, 
     {GrayLevel[0], PointSize[0.01], AbsoluteThickness[1.6]}}, {
     {RGBColor[1, 0, 0], PointSize[0.015], AbsoluteThickness[1.6]}, 
     {RGBColor[0, 0, 1], PointSize[0.01], AbsoluteThickness[1.6]}, 
     {GrayLevel[0], PointSize[0.01], AbsoluteThickness[
      1.6]}, {}, {}, {}, {}, {}, {}, {}}, {
     {RGBColor[1, 0, 0], PointSize[0.015], AbsoluteThickness[1.6]}, 
     {RGBColor[0, 0, 1], PointSize[0.01], AbsoluteThickness[1.6]}, 
     {GrayLevel[0], PointSize[0.01], AbsoluteThickness[
      1.6]}, {}, {}, {}, {}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 149.}, {0, 1.0495932456336081`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.87800938852789*^9, 3.878009412383337*^9}, 
   3.87800948824685*^9, {3.8780096553228207`*^9, 3.878009672984275*^9}, 
   3.878009709432572*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"fd158804-1a12-4b1b-b409-15ba6cc36d87"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"bseq", "[", 
     RowBox[{"Take", "[", 
      RowBox[{"qlist", ",", " ", "150"}], "]"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"-", "1"}], "]"}], "]"}], ",", "20"}], "]"}]], "Input",
 CellChangeTimes->{{3.878009691505685*^9, 3.878009697353109*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"0d825c75-3eeb-447e-8983-16a9b5efbdc8"],

Cell[BoxData["0.50740455976159263746424821718241284975`20."], "Output",
 CellChangeTimes->{3.878009697691072*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"6f436301-d391-41cb-bd67-acaf6b0bca30"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"RichardsonTransform", "[", 
      RowBox[{
       RowBox[{"bseq", "[", 
        RowBox[{"Take", "[", 
         RowBox[{"qlist", ",", " ", "150"}], "]"}], "]"}], ",", " ", "45"}], 
      "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"-", "1"}], "]"}], "]"}], ",", "50"}], "]"}], "-", 
  RowBox[{"1", "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.8780097219130783`*^9, 3.878009748176556*^9}, {
  3.8780097833457737`*^9, 3.8780097896799583`*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"7a17b10f-cb9d-4b5e-823d-e7982c3e1554"],

Cell[BoxData["7.44975636747941208968039223118748798863815398216812044475`30.\
173172065729126*^-21"], "Output",
 CellChangeTimes->{{3.878009731286545*^9, 3.8780097505701036`*^9}, {
  3.8780097868011007`*^9, 3.8780097934598083`*^9}},
 CellLabel->"Out[40]=",ExpressionUUID->"6796c430-a2db-49fc-a587-1b5851c83dd3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extracting the prefactor", "Section",
 CellChangeTimes->{{3.844171450887299*^9, 3.844171452912423*^9}, {
  3.848641815011495*^9, 3.848641816243886*^9}, {3.849433075987344*^9, 
  3.8494330770065727`*^9}, {3.877934503568592*^9, 3.877934510746976*^9}, {
  3.878009204774881*^9, 3.878009205062544*^9}, {3.878204234203397*^9, 
  3.8782042368433323`*^9}},
 FontSize->24,ExpressionUUID->"ddabadba-a7c7-4962-be75-b47d8eb0c9cd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cseq", "[", "list_", "]"}], ":=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "/", "3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"i", "+", 
         RowBox[{"1", "/", "2"}]}], ")"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"i", "+", "1"}], ")"}]}], " ", "/", 
       RowBox[{"Gamma", "[", 
        RowBox[{"i", "+", 
         RowBox[{"1", "/", "2"}]}], "]"}]}], 
      RowBox[{"list", "[", 
       RowBox[{"[", 
        RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "0", ",", 
       RowBox[{
        RowBox[{"Length", "[", "list", "]"}], "-", "2"}]}], "}"}]}], "]"}]}], 
  " ", ";"}]], "Input",
 CellChangeTimes->{{3.878009880535346*^9, 3.878009960821966*^9}, {
  3.8780099932867813`*^9, 3.878009993525691*^9}, {3.8780100301022387`*^9, 
  3.8780100365728273`*^9}, {3.878010075709963*^9, 3.878010077444528*^9}},
 CellLabel->
  "In[259]:=",ExpressionUUID->"cc80da53-a5af-4c86-ab8f-8f55d5f29a01"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"cseq", "[", 
   RowBox[{"Take", "[", 
    RowBox[{"qlist", ",", " ", "150"}], "]"}], "]"}], "[", 
  RowBox[{"[", "4", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.878009997734771*^9, 3.8780100076929197`*^9}, {
  3.8780100415342407`*^9, 3.878010041892569*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"ccc79afd-ed8b-4500-a5c2-edd724b80a55"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["37", 
   RowBox[{"90", " ", 
    SqrtBox[
     RowBox[{"3", " ", "\[Pi]"}]]}]]}]], "Output",
 CellChangeTimes->{
  3.8780100081543407`*^9, {3.878010039144051*^9, 3.8780100421942596`*^9}},
 CellLabel->"Out[48]=",ExpressionUUID->"e685a020-6ab3-422a-aa47-a507f18bb1f7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"cseq", "[", 
   RowBox[{"Take", "[", 
    RowBox[{"qlist", ",", " ", "150"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.878009974125836*^9, 3.878009977749442*^9}},
 CellLabel->"In[51]:=",ExpressionUUID->"28fbe5c8-efee-4db9-a779-8ab6172ad822"],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw1zQtUTAkcx/GplDZ2m9RK2FWEaPWk56RfIUPTY6bpOdXcmWRFWJHHoDor
srLy2MqmlVbttj2UsyHba1Apj0rS2JaMqOOZEmE71drj/uece+Z87u9+z99M
vlEUrcnhcNI/Pv//f/r1uxucTstX3a2rZV+Atfsn6mJ+u8Mvagclay5mZ/K1
J5lfYm2E2zZ7pk94eZn1FJx7yB0UN1M/HXYfUpjqlAbWpjBau8jLTKuR9Uxk
u60sE7o1sTbHg0c7wnV411jPwZ+P17TH6l5nbYHGMf0B62LyfOwwMd6pbXOD
9TeYnCrpnX2CbIVgt8oWz0GyDeIWn3S6wLvJ2haVTXfONCnIdvjrNC/6RSnZ
HgNiZ/vB++SFOHXfr8FNp5n1ImwbGZunmkd2wDDvxsWDK8iOKPx6JGM0muyE
tVeerC5KJDvDsUB0/n0G2QX1jQ0c52KyK7yzy7hltWQekjfPcsi4RXbDDG95
0dRu8mJsO+QaFT1AdsfV9I61x8fIQI7x6HDrxJZPTgJyb8nEFiasOR7INo5l
ys1p90Cc0HXpfmvaPVG5aNe1cmfaPbHuaXcNfwntS1A6esxJKKB9CY5W1av+
FtO+FOuGZnx4EU77UmTtaVUfW0X7MvSO7+rqWEf7MnSs6V9fHUe7F4zMUnx8
d9DuBX7FquNpibQvR8OmVtW+vbQvR6GdrZFzKu18dDbGPio8TDsfh89FxavT
aV8BdWDbyftZtK9A8fPb3fk5tK/ESU2Xnbw82ldCurtbmldAuze81NY+6mLa
vTHWc6npdRntAvh0pFh2ldMuwLd8z+y8Ctp9sP7mvq/4VbT7ICEo8OC1Wtp9
8cNLQd6CK7T7wj8+VXNzA+1+OHrQ0yK7ifaPDtTbXXiDdn9oVX3wz2lhDX8I
VAe6drbR9/5wtBYKPO6wVvqj/dW+M/0q6oUo3RGvm9pJvRCvbat9DO5TL0TN
aGJU8gPqhejZssms5yH1IjjJW0QLH1Mvwq8Gyy7E9VIvQr2sUiv3CfUiMKnG
j2qfUR8AMzwbanlBfQCeZHPv3uqjPgD1Hnzjhn7qA5Bac8Gt5DX1YgiiYm+m
vKFeDPs1zR5BQ9SLkbt8ItfkPfVibNVP+L31A/WBMJJoxO0epj4Qfhm+7TNG
qA+E3lS+VcUo9YG42pa7fhanle2DkBk416SXjCBw+hyW5GmwTgqC+fxYw0hN
1sogXGcySw21qA/GmRiVaz0ZwejLOdsZN476YLj6W5RM16Y+GIqzLW2XyZwQ
9O55GBOtQ30I5N/5pY0bT30IvndvjzxFVobg9ojWoJMu9aFwNpNEN5MRiu2X
BM3MZ9SHouaN37J+sjIUsdIX6l161IchRLvhvM4E6sPwc0zBPz+Sk8LQoXsk
atJE6sPg7nxR9hOZI0G8IueJ4efUS9C5mKt3hJwkwVRHK9WEL6iXQMNCwSST
OeHgiTrP/UtGON7E5fZu0Kc+HMqodI2HZGU4xjFvjYRc6iOAt4lWtWRE4MTp
7RJLA+ojsMW+pCCdrIxAYp1i5iiZE4nfstraV02iPhIZxYuvN5GTIvHHux7u
AkPqI7E3+3DZITJHivKrReV9ZEgxK8Znro8R9VJIqh0nFZKVUmgW3UvQ/pJ6
BnPeMVulZFMGB0Q5GhVkMLD0tJynP5k1w+Dl44C3q8hJDOTH52y4SD7FIDph
04mJxnSPgUtPfXIkWc2g6pjCtpTMkWHycEnBKNlUhig//oBgCt2XIWX/iEEW
mZFhi8DPoJecJING3aG3NiZ0X4Ztkq46BVkpw+WN9nuvkNUyCJ4G8yZMpfty
xNY/fyUkm8rhkrY6P5MMOfIbp8jvkRk5FEsXWJpOo/ty2MUVakeRT8kxLXvz
UN5H/weUJcyW
      "]]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.22222071129796883`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 149.}, {0.22222071129796883`, 0.25168727939166197`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.878009978197248*^9, 3.878009995748341*^9}, 
   3.878010044547559*^9, 3.8780100804224977`*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"dcb2e058-968a-44e7-9c96-ee190cae8395"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"2", "^", 
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}]}], "/", 
    RowBox[{"Pi", "^", 
     RowBox[{"(", 
      RowBox[{"3", "/", "2"}], ")"}]}]}], ",", "30"}], "]"}]], "Input",
 CellChangeTimes->{{3.8780101026696863`*^9, 3.878010110632833*^9}, {
  3.878010162500701*^9, 3.878010162954939*^9}},
 CellLabel->"In[55]:=",ExpressionUUID->"95fc332e-19bd-464a-b3be-00683d708619"],

Cell[BoxData["0.2539745437369638791430532197385440806202155971290916970346`30.\
"], "Output",
 CellChangeTimes->{3.8780101110752077`*^9, 3.878010163409342*^9},
 CellLabel->"Out[55]=",ExpressionUUID->"b0e4881e-4aeb-46bd-abf9-a6aef4bce70e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"cseq", "[", 
    RowBox[{"Take", "[", 
     RowBox[{"qlist", ",", " ", "150"}], "]"}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"-", "1"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.8780101258437767`*^9, 3.8780101313473473`*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"a56d1f11-36bf-49cd-af7a-9a6a0028aba7"],

Cell[BoxData["0.25168727939166197`"], "Output",
 CellChangeTimes->{3.8780101317352133`*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"3f2452bc-98df-4244-84d9-19339c7499c9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"RichardsonTransform", "[", 
      RowBox[{
       RowBox[{"cseq", "[", 
        RowBox[{"Take", "[", 
         RowBox[{"qlist", ",", " ", "150"}], "]"}], "]"}], ",", "65"}], "]"}],
      "[", 
     RowBox[{"[", 
      RowBox[{"-", "1"}], "]"}], "]"}], ",", "30"}], "]"}], "-", 
  RowBox[{
   RowBox[{"2", "^", 
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}]}], "/", 
   RowBox[{"Pi", "^", 
    RowBox[{"(", 
     RowBox[{"3", "/", "2"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8780101370049686`*^9, 3.878010172930956*^9}, {
  3.878204447460855*^9, 3.878204472024523*^9}},
 CellLabel->
  "In[269]:=",ExpressionUUID->"76a18611-21e6-4cf3-bfe9-f41dd1eca8ad"],

Cell[BoxData[
 RowBox[{"-", 
  "1.19018615986323736663148037439314301`8.670824706953168*^-22"}]], "Output",\

 CellChangeTimes->{{3.8780101596806297`*^9, 3.878010173647605*^9}, {
  3.8782044423995733`*^9, 3.8782044730973454`*^9}},
 CellLabel->
  "Out[269]=",ExpressionUUID->"1f6eea4e-5469-453c-89f3-7ead131e4e5f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cseq", "[", 
      RowBox[{"Take", "[", 
       RowBox[{"qlist", ",", " ", "150"}], "]"}], "]"}], ",", 
     RowBox[{"RichardsonTransform", "[", 
      RowBox[{
       RowBox[{"cseq", "[", 
        RowBox[{"Take", "[", 
         RowBox[{"qlist", ",", " ", "150"}], "]"}], "]"}], ",", " ", "1"}], 
      "]"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}], "/", 
        RowBox[{"Pi", "^", 
         RowBox[{"(", 
          RowBox[{"3", "/", "2"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "149"}], "}"}]}], "]"}]}], "}"}], ",", 
   " ", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.015", "]"}], ",", " ", "Red"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.01", "]"}], ",", " ", "Blue"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.01", "]"}], ",", " ", "Black"}], "}"}]}],
      "}"}]}], ",", " ", 
   RowBox[{"Joined", "->", 
    RowBox[{"{", 
     RowBox[{"False", ",", "False", ",", "  ", "True"}], "}"}]}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.87801019569125*^9, 3.8780102052282333`*^9}},
 CellLabel->"In[58]:=",ExpressionUUID->"3fb945fe-1e7b-434c-8e28-800346904237"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, {}, {}, 
     {GrayLevel[0], PointSize[0.01], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJxdzblqVVEYhuEPK0sLCwsJUUIQkRDHGIecncHEeUic4ng8kFpSpvtvwv5c
yn8Jdra5BC9BRUHOs2CzePbLxzo3+bp7cCLJt9/fn/vv+TnaP/pxOLf+ffTv
xzDrk/gUPo3P4LN4Hp/HC3gRX8AX8SW8hJfxZXwFX8XX8HV8A6/gm3gV38K3
8R18F6/hER5mXTjrdJwNOs4mHWeLjnOPjrNNx9mh49yn4zyg4zyk4zyi4zym
4zyh4zyl4zyj4zyf9YALN84L9rhw4+yyx4UbZ489Ltw4L9njwo3zij0u3Div
2ePCjfOGPS7cOG/Z48KNs88eF26cd+xx4cZ5zx4XbpwP7HHhxvnIHhdunE/s
ceHG+cweF26c8azn8YDHuPAUNz7G+cL7eMBjXHiKGx/jTHgfD3iMC0//+xcb
94vM
       "]]}}, {
     {RGBColor[1, 0, 0], PointSize[0.015], AbsoluteThickness[1.6], 
      PointBox[CompressedData["
1:eJw1zQtUTAkcx/GplDZ2m9RK2FWEaPWk56RfIUPTY6bpOdXcmWRFWJHHoDor
srLy2MqmlVbttj2UsyHba1Apj0rS2JaMqOOZEmE71drj/uece+Z87u9+z99M
vlEUrcnhcNI/Pv//f/r1uxucTstX3a2rZV+Atfsn6mJ+u8Mvagclay5mZ/K1
J5lfYm2E2zZ7pk94eZn1FJx7yB0UN1M/HXYfUpjqlAbWpjBau8jLTKuR9Uxk
u60sE7o1sTbHg0c7wnV411jPwZ+P17TH6l5nbYHGMf0B62LyfOwwMd6pbXOD
9TeYnCrpnX2CbIVgt8oWz0GyDeIWn3S6wLvJ2haVTXfONCnIdvjrNC/6RSnZ
HgNiZ/vB++SFOHXfr8FNp5n1ImwbGZunmkd2wDDvxsWDK8iOKPx6JGM0muyE
tVeerC5KJDvDsUB0/n0G2QX1jQ0c52KyK7yzy7hltWQekjfPcsi4RXbDDG95
0dRu8mJsO+QaFT1AdsfV9I61x8fIQI7x6HDrxJZPTgJyb8nEFiasOR7INo5l
ys1p90Cc0HXpfmvaPVG5aNe1cmfaPbHuaXcNfwntS1A6esxJKKB9CY5W1av+
FtO+FOuGZnx4EU77UmTtaVUfW0X7MvSO7+rqWEf7MnSs6V9fHUe7F4zMUnx8
d9DuBX7FquNpibQvR8OmVtW+vbQvR6GdrZFzKu18dDbGPio8TDsfh89FxavT
aV8BdWDbyftZtK9A8fPb3fk5tK/ESU2Xnbw82ldCurtbmldAuze81NY+6mLa
vTHWc6npdRntAvh0pFh2ldMuwLd8z+y8Ctp9sP7mvq/4VbT7ICEo8OC1Wtp9
8cNLQd6CK7T7wj8+VXNzA+1+OHrQ0yK7ifaPDtTbXXiDdn9oVX3wz2lhDX8I
VAe6drbR9/5wtBYKPO6wVvqj/dW+M/0q6oUo3RGvm9pJvRCvbat9DO5TL0TN
aGJU8gPqhejZssms5yH1IjjJW0QLH1Mvwq8Gyy7E9VIvQr2sUiv3CfUiMKnG
j2qfUR8AMzwbanlBfQCeZHPv3uqjPgD1Hnzjhn7qA5Bac8Gt5DX1YgiiYm+m
vKFeDPs1zR5BQ9SLkbt8ItfkPfVibNVP+L31A/WBMJJoxO0epj4Qfhm+7TNG
qA+E3lS+VcUo9YG42pa7fhanle2DkBk416SXjCBw+hyW5GmwTgqC+fxYw0hN
1sogXGcySw21qA/GmRiVaz0ZwejLOdsZN476YLj6W5RM16Y+GIqzLW2XyZwQ
9O55GBOtQ30I5N/5pY0bT30IvndvjzxFVobg9ojWoJMu9aFwNpNEN5MRiu2X
BM3MZ9SHouaN37J+sjIUsdIX6l161IchRLvhvM4E6sPwc0zBPz+Sk8LQoXsk
atJE6sPg7nxR9hOZI0G8IueJ4efUS9C5mKt3hJwkwVRHK9WEL6iXQMNCwSST
OeHgiTrP/UtGON7E5fZu0Kc+HMqodI2HZGU4xjFvjYRc6iOAt4lWtWRE4MTp
7RJLA+ojsMW+pCCdrIxAYp1i5iiZE4nfstraV02iPhIZxYuvN5GTIvHHux7u
AkPqI7E3+3DZITJHivKrReV9ZEgxK8Znro8R9VJIqh0nFZKVUmgW3UvQ/pJ6
BnPeMVulZFMGB0Q5GhVkMLD0tJynP5k1w+Dl44C3q8hJDOTH52y4SD7FIDph
04mJxnSPgUtPfXIkWc2g6pjCtpTMkWHycEnBKNlUhig//oBgCt2XIWX/iEEW
mZFhi8DPoJecJING3aG3NiZ0X4Ztkq46BVkpw+WN9nuvkNUyCJ4G8yZMpfty
xNY/fyUkm8rhkrY6P5MMOfIbp8jvkRk5FEsXWJpOo/ty2MUVakeRT8kxLXvz
UN5H/weUJcyW
       "]]}, 
     {RGBColor[0, 0, 1], PointSize[0.01], AbsoluteThickness[1.6], 
      PointBox[CompressedData["
1:eJw9zQk41Hkcx/GpbLJK2tSKdiOy6FiNo9LhY9yGGTNjHOOaUZ52l9STY1u1
mgqhGrstFdsh8UhqQ4djqXRhVZRUq3Tr4BGtqEi2fXZ+33meeeZ5z+f/+n+N
w1eLI0ZzOJzMT9//fv//9DpMOpRRcPvORQf1H0j+vNqixaJc3eNg+FVUa+zH
8+rWRfswN3zArV7denAocPPeILmibn3kRd/dUmfWpO7pKNE08a2OaVa3ESzG
RPPFnaxnYih96H6r/nV1m0Jv4HnymOmszSDY2rj1+TjW5tDKKbOZ1s28JRat
ro+XNrOeA0lBo2/Iadbz0GeWlJCey9oKqT9pC3pUrOejybi1Q3sTay6ubVeu
sY5nbY331f/onFnF2gY2c7Xqp69kbYui7IeD7QrWdtC4PtJ+JIT1AryKy8zj
yVgvhNgwMirOn/UijO+6OTxDytoe1jOdhOYS1otxuPDZqPUi1kuwMGlTkpYP
66XQit94tl7Aehne2JwwKfFm7YDYQuFIhRdroKfYXuM+X91KYH1kW68Ba44j
tJ6884nyZLsjSp12CJs82M7Dgpr4TEfWSh6ME2ssa93Z7gTul0NRXqyVThC5
8gYeubHdGQ9GB+1SslY6ozvwZ/dvaHfBobe9s1td2e6C/GNGiWmsOa7oV13L
cqLdFbUWlg9G0+6GsB3Zdy67sN0NFx/r6maw5rhjTdY9oyDa3RHFrS+1pN0D
9xp/iRl2ZrsHupZlzWhhzfHEyLrK+GLaPZE1FIMU2vnIT//osZx2PhRO+RE8
2r3wNsL8BxPavRDV58gdS7s38rvN93Y6sd0bvTu5ac2sOQLoyhPay2kXYCJn
18Zc2oWQ7BMHpNMuRIlLgjiOdh/ouOXKFKzhA+2svlABPe+DpsipwiWsz/lA
f/Og4WzyIpTZ1pYbkBdhJ/fAFG3yIhSaXbD4wGNehCQTh5fdrDlidAS98XjI
GmJ09it5LayVYsw9+e1fl8mLMezw8k4VeQkOdZitPE5egsPZz1blk5dAzyT3
WTZ5CTT5ixszyPviev/YqSnkfTFuQmntBvK+eGrq0BBD3hctDZrmkeSlMI04
+nc4eSluF01uk5GXwnDDilkS8lKo3EZV8Mn74UDlFpUzeT9k3qooWEreD4Xy
fYN25P1QliZLtyLvj7QXPLEleX88KW4SmpL3h+yz/cqvyftjXV3UY33yAYjl
GsRMJv+puw5a6ZAPwA0Dw2la5AMwcuy0pQb5QIyvqlk+4sh8IOZ9yDg/yFoZ
iOq4PJcB1ucCEWuc2PWaNUeGt2fPlHWTl+FI5aScl+Rl4OvZ5naQl6E4YeDC
I/JBsJJyNe6TD0LT6xthbeSDIKpqar1FPghtP86JaCEfjMN578Y3kw/G/BrB
lSvkg1FbKclrIB+Me9/bqS6TD0HJwLyMC+RD8EqRmH+OfAjW6URfrSEfAqmP
UOtP8qFYPWa9fwX5UOw2F5WfIh+K+NSF5ifIh+J10P6iEvJhOP6+3/4P8mFY
kVpxt5h8GHJOrdhWRD4Mv69J9CgkL4egSDWlgLWRHKVfmPTk0fvkqHtxtTWX
tVyOU5WzGvbT++V4Ov9S/V7WuXL0dXrezKF7cvCXBnbtYf1QDlu9XRN2030F
Fl88Yp9F9xWof+K09je6r0DdrEknf6X7CvDsLo1k0P1Pz++ZIlXRfQVUqVUn
ttN9BWzaog230X0FNB/0bEuj++Go9BjWSKX74VirF5iSQvfDYfld3cRkuh8O
62Sdg1vofjh6jg4s2vyp/wV4PMIP
       "]]}, 
     {GrayLevel[0], PointSize[0.01], AbsoluteThickness[1.6]}}, {
     {RGBColor[1, 0, 0], PointSize[0.015], AbsoluteThickness[1.6]}, 
     {RGBColor[0, 0, 1], PointSize[0.01], AbsoluteThickness[1.6]}, 
     {GrayLevel[0], PointSize[0.01], AbsoluteThickness[
      1.6]}, {}, {}, {}, {}, {}, {}, {}}, {
     {RGBColor[1, 0, 0], PointSize[0.015], AbsoluteThickness[1.6]}, 
     {RGBColor[0, 0, 1], PointSize[0.01], AbsoluteThickness[1.6]}, 
     {GrayLevel[0], PointSize[0.01], AbsoluteThickness[
      1.6]}, {}, {}, {}, {}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 149.}, {-0.16286750396763996`, 0.2673348243405098}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.878010206379161*^9},
 CellLabel->"Out[58]=",ExpressionUUID->"db3cdc31-d90a-456e-bd2d-f870a7620062"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Borel-Pade resummation", "Section",
 CellChangeTimes->{{3.4022248832172623`*^9, 3.402224890038163*^9}, {
  3.404128014704677*^9, 3.4041280195924387`*^9}, {3.530702576782583*^9, 
  3.530702583630056*^9}, {3.7031728813635883`*^9, 3.703172885793404*^9}, {
  3.877510855530293*^9, 3.877510859578182*^9}, {3.878204087117387*^9, 
  3.8782040964530773`*^9}, {3.878782818341378*^9, 3.878782826421438*^9}},
 FontSize->36,ExpressionUUID->"e3c7eec4-6eed-40d4-aa0b-e01463a458b8"],

Cell["\<\
We calculate the Pade approximant of the perturbative series and its numeric \
Borel resummation. The parameter a is a phase which is used to 
perform lateral Borel resummations, and here we can put it to 1\
\>", "Text",
 CellChangeTimes->{{3.404128219025543*^9, 3.404128233779027*^9}, {
  3.7031750902539873`*^9, 3.703175091228704*^9}, {3.877934842862117*^9, 
  3.8779348897127028`*^9}, {3.877934934107234*^9, 3.877934959034687*^9}, {
  3.8779622037648973`*^9, 3.877962208393756*^9}, {3.8779637475006857`*^9, 
  3.877963771698166*^9}, {3.8787841102535048`*^9, 3.87878414236509*^9}, {
  3.878784208175716*^9, 
  3.878784228011269*^9}},ExpressionUUID->"c223bf43-ce4c-4f4d-b7ed-\
aa2d71220fe9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BTqlist", "[", 
    RowBox[{"g_", ",", "d_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{"qlist", ",", "d"}], "]"}], ".", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"g", "^", 
        RowBox[{"(", 
         RowBox[{"i", "-", "1"}], ")"}]}], "/", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"i", "-", "1"}], ")"}], "!"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "d"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PadBT", "[", 
    RowBox[{"u_", ",", "d_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"PadeApproximant", "[", 
     RowBox[{
      RowBox[{"BTqlist", "[", 
       RowBox[{"g", ",", 
        RowBox[{"d", "+", "1"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"g", ",", "0", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"IntegerPart", "[", 
           RowBox[{"d", "/", "2"}], "]"}], ",", 
          RowBox[{"IntegerPart", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"d", "+", "1"}], ")"}], "/", "2"}], "]"}]}], "}"}]}], 
       "}"}]}], "]"}], "/.", 
    RowBox[{"g", "\[Rule]", "u"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"BPR", "[", 
    RowBox[{"x_", ",", "a_", ",", "d_", ",", " ", "prec_"}], "]"}], ":=", 
   RowBox[{"a", " ", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "a"}], "  ", "t"}], "]"}], 
       RowBox[{"PadBT", "[", " ", 
        RowBox[{
         RowBox[{"a", "  ", "t", "  ", "x"}], ",", "d"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", " ", "Infinity"}], "}"}], ",", " ", 
      RowBox[{"WorkingPrecision", "\[Rule]", "prec"}]}], "]"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.878782862849395*^9, 3.87878292902255*^9}, {
   3.878782983199827*^9, 3.878783013860753*^9}, {3.878783389705258*^9, 
   3.878783401435705*^9}, 3.878783441992722*^9, {3.878783484055381*^9, 
   3.8787835328758383`*^9}},
 CellLabel->
  "In[105]:=",ExpressionUUID->"d80c2df2-bb2f-4562-a231-127c40100eab"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BTqlist", "[", 
  RowBox[{"g", ",", " ", "4"}], "]"}]], "Input",
 CellChangeTimes->{{3.878782972297925*^9, 3.8787829754389277`*^9}, {
  3.878783496497651*^9, 3.878783496731493*^9}},
 CellLabel->"In[99]:=",ExpressionUUID->"7dee251a-e1a1-44d3-8499-ac0ff827b62f"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], "+", 
  FractionBox[
   RowBox[{"3", " ", "g"}], "4"], "-", 
  FractionBox[
   RowBox[{"21", " ", 
    SuperscriptBox["g", "2"]}], "16"], "+", 
  FractionBox[
   RowBox[{"111", " ", 
    SuperscriptBox["g", "3"]}], "32"]}]], "Output",
 CellChangeTimes->{{3.8787829759351883`*^9, 3.8787830311160793`*^9}, 
   3.878783206943899*^9, 3.878783409685103*^9, {3.8787834460454187`*^9, 
   3.878783456146406*^9}, 3.878783496973813*^9},
 CellLabel->"Out[99]=",ExpressionUUID->"e13f4f7a-707c-4cf8-9b22-eb0a78d33dfb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PadBT", "[", 
  RowBox[{"u", ",", "3"}], "]"}]], "Input",
 CellChangeTimes->{{3.87878347279951*^9, 3.8787834743676643`*^9}},
 CellLabel->
  "In[103]:=",ExpressionUUID->"bf394669-681d-4f5b-ba43-643699a45374"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   FractionBox["1", "2"], "+", 
   FractionBox[
    RowBox[{"97", " ", "u"}], "52"]}], 
  RowBox[{"1", "+", 
   FractionBox[
    RowBox[{"29", " ", "u"}], "13"], "-", 
   FractionBox[
    RowBox[{"75", " ", 
     SuperscriptBox["u", "2"]}], "104"]}]]], "Output",
 CellChangeTimes->{{3.878783474884523*^9, 3.878783486818434*^9}, 
   3.878783522312106*^9},
 CellLabel->
  "Out[103]=",ExpressionUUID->"13888f43-b85a-4566-a72b-6f994d22b7d0"]
}, Open  ]],

Cell["\<\
These are the Borel resummations as we increase the number of terms in the \
series (from 20 t0 180). They approach the value obtained by e.g. numerical \
diagonalization\
\>", "Text",
 CellChangeTimes->{{3.404128219025543*^9, 3.404128233779027*^9}, {
  3.7031750902539873`*^9, 3.703175091228704*^9}, {3.877934842862117*^9, 
  3.8779348897127028`*^9}, {3.877934934107234*^9, 3.877934959034687*^9}, {
  3.8779622037648973`*^9, 3.877962208393756*^9}, {3.8779637475006857`*^9, 
  3.877963771698166*^9}, {3.8787841102535048`*^9, 3.87878414236509*^9}, {
  3.878784208175716*^9, 
  3.878784288119172*^9}},ExpressionUUID->"e444d781-7041-4098-8354-\
314f7090060f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"BPR", "[", 
       RowBox[{"1", ",", "1", ",", 
        RowBox[{"20", "*", "i"}], ",", " ", "50"}], "]"}], "//", "Quiet"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", " ", "1", ",", " ", "9"}], "}"}]}], "]"}], 
  " "}]], "Input",
 CellChangeTimes->{{3.878782933352775*^9, 3.878782949586657*^9}, {
  3.878783540402392*^9, 3.8787835540159883`*^9}, {3.878783830548273*^9, 
  3.878783899528522*^9}},
 CellLabel->
  "In[118]:=",ExpressionUUID->"aca15cab-f37b-40ee-9247-f80da0959947"],

Cell[CellGroupData[{

Cell[BoxData["0.\
80376974382460625284140320874006029650073234695469601984469151799682759133259`\
50."], "Print",
 CellChangeTimes->{{3.878783866658383*^9, 3.8787839002817707`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"5eef6c0c-5efa-488e-bf69-4407eda1886a"],

Cell[BoxData["0.\
80377064812837328657041146035384254310773251295617896944642584816507291886933`\
50."], "Print",
 CellChangeTimes->{{3.878783866658383*^9, 3.878783900507846*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"ed0982d1-7d25-4c28-846a-d8cddc56fa86"],

Cell[BoxData["0.\
80377065122229621022009075469719516519806586399074225566181471059646603036528`\
50."], "Print",
 CellChangeTimes->{{3.878783866658383*^9, 3.8787839011423388`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"d2e8ba0e-8dfb-4266-923d-51125ebfa3f2"],

Cell[BoxData["0.\
80377065123421951090695714147822248549291884046614685648676844841739464070552`\
50."], "Print",
 CellChangeTimes->{{3.878783866658383*^9, 3.878783902876519*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"ca1b04a5-30f6-408e-a482-de59069b1e32"],

Cell[BoxData["0.\
8037706512342737262931158450271084281530809360593910299658857781553956410393`\
50."], "Print",
 CellChangeTimes->{{3.878783866658383*^9, 3.878783908171736*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"013e7a51-f0d5-48f9-a5e6-5dc7884e7880"],

Cell[BoxData["0.\
80377065123427376884167165225157787800326786964303199704225925405699704763959`\
50."], "Print",
 CellChangeTimes->{{3.878783866658383*^9, 3.87878388535625*^9}, 
   3.878783921505755*^9},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"8b4244a2-1a88-425f-a3e8-94cd2f96f171"],

Cell[BoxData["0.\
80377065123427376934880243620910013078296280403990290469834762194590922203457`\
50."], "Print",
 CellChangeTimes->{{3.878783866658383*^9, 3.87878388535625*^9}, 
   3.878783953654036*^9},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"ad3fcf77-ecaf-424c-9a84-4e8bd844a952"],

Cell[BoxData["0.\
80377065123427376935403371887780216506075272987981294566119641931893224713799`\
50."], "Print",
 CellChangeTimes->{{3.878783866658383*^9, 3.87878388535625*^9}, 
   3.878784024036327*^9},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"1a4feda6-6118-4f90-ad08-0f839553ecb0"],

Cell[BoxData["0.\
80377065123427376935408623567748703519985828019345538829000027505675755710454`\
50."], "Print",
 CellChangeTimes->{{3.878783866658383*^9, 3.87878388535625*^9}, 
   3.8787841649655237`*^9},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"fa8d3561-5935-450d-8d72-61b914fe232f"]
}, Open  ]]
}, Open  ]],

Cell["\<\
By plotting the poles of its Pade approximant, we can locate the \
singularities of the Borel transform\
\>", "Text",
 CellChangeTimes->{{3.404128219025543*^9, 3.404128233779027*^9}, {
  3.7031750902539873`*^9, 3.703175091228704*^9}, {3.877934842862117*^9, 
  3.8779348897127028`*^9}, {3.877934934107234*^9, 3.877934959034687*^9}, {
  3.8779622037648973`*^9, 3.877962208393756*^9}, {3.8779637475006857`*^9, 
  3.877963771698166*^9}, {3.8787841102535048`*^9, 3.87878414236509*^9}, {
  3.878784208175716*^9, 3.878784228011269*^9}, {3.882250102754183*^9, 
  3.8822501380676403`*^9}},ExpressionUUID->"cfc5154b-dcc1-4b89-b7f8-\
6d0dfbf50cf1"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"qlist", "[", 
         RowBox[{"[", "n", "]"}], "]"}], "/", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"n", "-", "1"}], ")"}], "!"}]}], ",", "300"}], "]"}], 
     SuperscriptBox["x", 
      RowBox[{"n", "-", "1"}]]}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "1", ",", "186"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PadeApproximant", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", 
      RowBox[{"{", 
       RowBox[{"93", ",", "92"}], "}"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"li", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", "#", "]"}], ",", 
        RowBox[{"Im", "[", "#", "]"}]}], "}"}], "&"}], "/@", 
     RowBox[{"(", 
      RowBox[{"x", "/.", 
       RowBox[{"NSolve", "[", 
        RowBox[{
         RowBox[{"0", "\[Equal]", 
          RowBox[{"1", "/", "%"}]}], ",", "x", ",", " ", 
         RowBox[{"WorkingPrecision", "\[Rule]", "300"}]}], "]"}]}], ")"}]}], "//",
     "Quiet"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{"%", ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "Large", "]"}], ",", " ", "Red"}], "}"}]}]}],
    "]"}], "//", "Quiet"}]}], "Input",
 CellChangeTimes->{{3.8774905982588587`*^9, 3.877490599874394*^9}, {
   3.877491030906774*^9, 3.877491103446076*^9}, 3.8774927151503687`*^9, {
   3.8774927670607233`*^9, 3.877492790674818*^9}, {3.877492866149818*^9, 
   3.877492870449667*^9}, {3.8774929060905323`*^9, 3.8774930124474583`*^9}, {
   3.877493151911718*^9, 3.8774931718775063`*^9}, {3.877494544633151*^9, 
   3.877494551471903*^9}, {3.877494650814958*^9, 3.877494671886106*^9}, {
   3.877494785142297*^9, 3.8774948242199583`*^9}, {3.8774948717327023`*^9, 
   3.877494897666757*^9}, {3.877495017178746*^9, 3.877495019408374*^9}, {
   3.877496837016552*^9, 3.8774968866213093`*^9}, {3.877513900609647*^9, 
   3.877513910630989*^9}, {3.877928512387087*^9, 3.87792851500305*^9}, {
   3.877928587151341*^9, 3.877928675674202*^9}, {3.87792871701381*^9, 
   3.877928730427953*^9}, {3.877928760785501*^9, 3.877928805680553*^9}, {
   3.877928835847952*^9, 3.8779288421282263`*^9}},
 CellLabel->
  "In[167]:=",ExpressionUUID->"e831e4b1-81e4-4831-ae3b-7b0b6fe0908b"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[1, 0, 0], PointSize[Large], AbsoluteThickness[1.6], 
    PointBox[CompressedData["
1:eJxd0A1MzHEYB/C/u6uYkruG06zuKsJS0TVdxT+13tapq3N6uaOJqKyXuyUS
602Yt7JYoVLWkEjvZVP//0QmE0LpVXfXm5NzyUlRYeP5bf9ne/bssz179uzL
jYgPiqRhGCb5039nvEtOvCBtP4n9q8RMNeOXdAd4ZY0osO6nF3hTR4QmzGML
uOOVk0MWkwe+FRk4W6qyAWd2FZWxE1aDixwbV01YcMCxzJC11+lssHZNRxM9
jUGGZwxyrr2nkxS7PZfmZubaLyT96iNL8sVTBMW4bkVU8eFEBhkZE9Dua4uR
FLvd9msYHjNnkFLfqPS3e2cIinErL0GhIINOZne2GmjDdATF+MR5ZxH/KY3U
cEhNu+UEQTEeE+ehNMVo5EnyRt3osJqgGF90Jam1bf0CUtGsllU5DxEU4/IZ
bSHbHSMNqxQeldw+gmKcHz6y7VLyHFFR0B+VkPqKoBhf9PreD1bsLPE/z3WG
Pp4Wh2aIY+mOC7ChWoJi/JlZsx7vlI6wZfVqNzjdJijG6+72Wtlv/Qb3Fu+d
jzYP/gquTn/knKfRgmuLXbnuLC2RKKcPLBOeIyjG9aZZQlO6BvavPr2vatw5
Dj6q3F5R+U4NbrN09NKlfQT3xHiKxZIxsPwEO2+PZBTMPMK++fnwCDi/3c0G
Lx8Gm/dba8pnh8DlZvUpm7yR5wtTmZwiFdjd2oY3jSEH0Pz0D8QpwcLT81Lh
sALMN/4+1b0PObDh8pqd44NghoFwIy8FeSzRwEG3FLmBm2onCPsA3nX8YPGD
ogHwgP6kY5ymH/2XM6Cq8UF+VB8mVt7tA1+4Y+Sy2xS5ZW6sxci4F2wkK2F4
Xu4BS+qUIS8tkF1Y3SNeDd3gvG/LN/sHIX9crziZPfkeHJrnsPbhVWQT16wv
Z72RH7O6Kh5Od4EXnglqYlYh28dfOSOKRU5W97kG2CLzg9+EdE52gj+J7sub
m5BLL/mODp5FZkjIAtPdyFK54pkfD9nO40lL8BLk4mTWa6vxd+CLuTJawQtk
V0mrcVk1cnR3B9/5GrKoftLO7RSySXTV9L0kZMGKcdWRaGQuKZPlhyP7SLv8
9UOR9ThJvs1i5N+Sse9g
     "]]}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1., 0.}, {-1., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.877927094240695*^9, 3.877928527715541*^9, {3.8779286002917223`*^9, 
   3.8779286464459047`*^9}, 3.877928702605768*^9, {3.877928750350425*^9, 
   3.877928826844677*^9}, 3.877928864285125*^9},
 CellLabel->
  "Out[170]=",ExpressionUUID->"cbfe7e39-8f2f-494f-830a-e14e95300bab"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", " ", 
  RowBox[{"%170", ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "Large", "]"}], ",", "Black", ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "1"}], "/", "3"}], ",", "0"}], "}"}], "]"}]}], "}"}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.877928881736249*^9, 3.877928883453061*^9}},
 CellLabel->
  "In[171]:=",ExpressionUUID->"0ab2931c-78ca-4573-81cb-26f1a9c383a9"],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {RGBColor[1, 0, 0], PointSize[Large], AbsoluteThickness[1.6], 
     PointBox[CompressedData["
1:eJxd0A1MzHEYB/C/u6uYkruG06zuKsJS0TVdxT+13tapq3N6uaOJqKyXuyUS
602Yt7JYoVLWkEjvZVP//0QmE0LpVXfXm5NzyUlRYeP5bf9ne/bssz179uzL
jYgPiqRhGCb5039nvEtOvCBtP4n9q8RMNeOXdAd4ZY0osO6nF3hTR4QmzGML
uOOVk0MWkwe+FRk4W6qyAWd2FZWxE1aDixwbV01YcMCxzJC11+lssHZNRxM9
jUGGZwxyrr2nkxS7PZfmZubaLyT96iNL8sVTBMW4bkVU8eFEBhkZE9Dua4uR
FLvd9msYHjNnkFLfqPS3e2cIinErL0GhIINOZne2GmjDdATF+MR5ZxH/KY3U
cEhNu+UEQTEeE+ehNMVo5EnyRt3osJqgGF90Jam1bf0CUtGsllU5DxEU4/IZ
bSHbHSMNqxQeldw+gmKcHz6y7VLyHFFR0B+VkPqKoBhf9PreD1bsLPE/z3WG
Pp4Wh2aIY+mOC7ChWoJi/JlZsx7vlI6wZfVqNzjdJijG6+72Wtlv/Qb3Fu+d
jzYP/gquTn/knKfRgmuLXbnuLC2RKKcPLBOeIyjG9aZZQlO6BvavPr2vatw5
Dj6q3F5R+U4NbrN09NKlfQT3xHiKxZIxsPwEO2+PZBTMPMK++fnwCDi/3c0G
Lx8Gm/dba8pnh8DlZvUpm7yR5wtTmZwiFdjd2oY3jSEH0Pz0D8QpwcLT81Lh
sALMN/4+1b0PObDh8pqd44NghoFwIy8FeSzRwEG3FLmBm2onCPsA3nX8YPGD
ogHwgP6kY5ymH/2XM6Cq8UF+VB8mVt7tA1+4Y+Sy2xS5ZW6sxci4F2wkK2F4
Xu4BS+qUIS8tkF1Y3SNeDd3gvG/LN/sHIX9crziZPfkeHJrnsPbhVWQT16wv
Z72RH7O6Kh5Od4EXnglqYlYh28dfOSOKRU5W97kG2CLzg9+EdE52gj+J7sub
m5BLL/mODp5FZkjIAtPdyFK54pkfD9nO40lL8BLk4mTWa6vxd+CLuTJawQtk
V0mrcVk1cnR3B9/5GrKoftLO7RSySXTV9L0kZMGKcdWRaGQuKZPlhyP7SLv8
9UOR9ThJvs1i5N+Sse9g
      "]]}, {{}, {}}}, 
   {GrayLevel[0], PointSize[Large], 
    PointBox[NCache[{Rational[-1, 3], 0}, {-0.3333333333333333, 0}]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1., 0.}, {-1., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.877928884504162*^9},
 CellLabel->
  "Out[171]=",ExpressionUUID->"255e9ed4-41a2-47ea-8120-5c94f437ddad"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1142, 762},
WindowMargins->{{46, Automatic}, {Automatic, 0}},
FrontEndVersion->"13.1 for Mac OS X x86 (64-bit) (June 16, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"e2951824-86d1-4881-a52a-0e9f37ab98b4"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 612, 10, 160, "Title",ExpressionUUID->"00cf2cbc-c2a7-44f7-a290-c46b23a76398"],
Cell[CellGroupData[{
Cell[1217, 36, 424, 6, 77, "Section",ExpressionUUID->"35011f57-1904-45ac-9aaa-714f17b3f713"],
Cell[1644, 44, 654, 11, 58, "Text",ExpressionUUID->"75dace61-bd05-45ef-a6ac-767814606278"],
Cell[2301, 57, 1550, 41, 241, "Input",ExpressionUUID->"ba8ebf3e-4c40-42a9-bb50-b0509f9b3a0e"],
Cell[CellGroupData[{
Cell[3876, 102, 232, 4, 30, "Input",ExpressionUUID->"ba0acab6-1f31-421f-9faa-b15fc0a03216"],
Cell[4111, 108, 383, 11, 50, "Output",ExpressionUUID->"d9bc2071-8f45-4fcc-88fe-8d41fa049bcf"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4543, 125, 444, 6, 77, "Section",ExpressionUUID->"4a7c0eec-1c91-44ca-8b1b-eb3f07510506"],
Cell[4990, 133, 739, 13, 58, "Text",ExpressionUUID->"652e2606-3418-4316-8ba8-a05c7c89aaba"],
Cell[5732, 148, 1515, 41, 139, "Input",ExpressionUUID->"73c062a3-6779-4bb3-8fe1-85c44570339d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7284, 194, 313, 4, 62, "Section",ExpressionUUID->"b678563a-bf77-473e-9c34-e3425a93a247"],
Cell[7600, 200, 478, 9, 35, "Text",ExpressionUUID->"358b2529-95cb-4d09-be40-9ac4d9cbf210"],
Cell[8081, 211, 703, 20, 30, "Input",ExpressionUUID->"e47b30c0-1d22-406b-8dab-e5fe8d1c5d5c"],
Cell[8787, 233, 372, 7, 35, "Text",ExpressionUUID->"083f63d4-2b9c-4007-aec4-784cae5fcad8"],
Cell[CellGroupData[{
Cell[9184, 244, 571, 15, 30, "Input",ExpressionUUID->"a57d9d89-9477-4a2c-9e1f-8bf2d55b25aa"],
Cell[9758, 261, 3201, 69, 224, "Output",ExpressionUUID->"27762a79-b844-4c28-9a27-42f540c3b06f"]
}, Open  ]],
Cell[12974, 333, 347, 5, 35, "Text",ExpressionUUID->"b08cce25-c1bd-4a72-9195-0dc2283d6fb2"],
Cell[CellGroupData[{
Cell[13346, 342, 504, 13, 30, "Input",ExpressionUUID->"864c35fb-77ab-4566-a64a-8d6b9100ac5e"],
Cell[13853, 357, 213, 4, 34, "Output",ExpressionUUID->"ca984791-8c56-4c97-90f0-146918078c97"]
}, Open  ]],
Cell[14081, 364, 423, 8, 35, "Text",ExpressionUUID->"480bfaa0-f7c0-4aac-b96e-fdf31285428f"],
Cell[CellGroupData[{
Cell[14529, 376, 1153, 36, 52, "Input",ExpressionUUID->"76a83de9-8e36-4616-ae62-5b5c779e333b"],
Cell[15685, 414, 3685, 78, 230, "Output",ExpressionUUID->"87c64b15-2169-43f8-860a-ccb102c19fab"]
}, Open  ]],
Cell[19385, 495, 519, 9, 35, "Text",ExpressionUUID->"fc3036c4-2a97-42d2-a8cd-8704ba5c40e0"],
Cell[CellGroupData[{
Cell[19929, 508, 1640, 50, 73, "Input",ExpressionUUID->"2658b1c3-28a5-49f3-823a-507df62d9321"],
Cell[21572, 560, 5654, 113, 229, "Output",ExpressionUUID->"8da80739-469f-4729-b78d-7ba56d6d41d1"]
}, Open  ]],
Cell[27241, 676, 532, 9, 35, "Text",ExpressionUUID->"c47d972e-a5bc-4202-a9e7-ef7f019a46a0"],
Cell[CellGroupData[{
Cell[27798, 689, 605, 16, 30, "Input",ExpressionUUID->"a0852e17-4f22-4ade-9ce9-08b12f6d8636"],
Cell[28406, 707, 315, 7, 34, "Output",ExpressionUUID->"a7da1b7a-b2a7-4910-8e0f-d6b8ff562ec3"]
}, Open  ]],
Cell[28736, 717, 536, 10, 35, "Text",ExpressionUUID->"939b9383-d365-4db8-aece-4c3c1cfc8cd6"],
Cell[CellGroupData[{
Cell[29297, 731, 640, 16, 30, "Input",ExpressionUUID->"71e9ff02-fe95-46b3-abd0-b962d1a523bf"],
Cell[29940, 749, 339, 6, 34, "Output",ExpressionUUID->"06a5b1b7-4314-477f-b655-a1cc690fea7c"]
}, Open  ]],
Cell[30294, 758, 645, 11, 35, "Text",ExpressionUUID->"3f05cd8e-c09c-444b-bf09-d32f27ee4224"],
Cell[CellGroupData[{
Cell[30964, 773, 796, 20, 30, "Input",ExpressionUUID->"ce82c896-2810-4f0e-8f66-905c888c7561"],
Cell[31763, 795, 280, 6, 34, "Output",ExpressionUUID->"faf0f204-d4b8-42d1-bf85-3e911922fe7d"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[32092, 807, 364, 5, 62, "Section",ExpressionUUID->"c0ba25b5-a58c-48a2-abe0-da62b4700d91"],
Cell[32459, 814, 1440, 41, 52, "Input",ExpressionUUID->"f770ab96-4a7e-4669-a1af-fdb8ec982cb0"],
Cell[CellGroupData[{
Cell[33924, 859, 333, 7, 30, "Input",ExpressionUUID->"4ba294b7-6139-4faf-90b9-fb1b7aeeefc8"],
Cell[34260, 868, 3495, 73, 246, "Output",ExpressionUUID->"90b5bcc8-4110-4df6-aa7b-8a7b4a0a8e3b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37792, 946, 1509, 42, 73, "Input",ExpressionUUID->"fc025a79-b317-4a45-baf9-34d0b4aafb4b"],
Cell[39304, 990, 6330, 123, 246, "Output",ExpressionUUID->"fd158804-1a12-4b1b-b409-15ba6cc36d87"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45671, 1118, 403, 10, 30, "Input",ExpressionUUID->"0d825c75-3eeb-447e-8983-16a9b5efbdc8"],
Cell[46077, 1130, 192, 2, 34, "Output",ExpressionUUID->"6f436301-d391-41cb-bd67-acaf6b0bca30"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46306, 1137, 606, 16, 30, "Input",ExpressionUUID->"7a17b10f-cb9d-4b5e-823d-e7982c3e1554"],
Cell[46915, 1155, 311, 4, 34, "Output",ExpressionUUID->"6796c430-a2db-49fc-a587-1b5851c83dd3"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47275, 1165, 425, 6, 62, "Section",ExpressionUUID->"ddabadba-a7c7-4962-be75-b47d8eb0c9cd"],
Cell[47703, 1173, 1165, 34, 30, "Input",ExpressionUUID->"cc80da53-a5af-4c86-ab8f-8f55d5f29a01"],
Cell[CellGroupData[{
Cell[48893, 1211, 374, 8, 30, "Input",ExpressionUUID->"ccc79afd-ed8b-4500-a5c2-edd724b80a55"],
Cell[49270, 1221, 310, 8, 54, "Output",ExpressionUUID->"e685a020-6ab3-422a-aa47-a507f18bb1f7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49617, 1234, 305, 6, 30, "Input",ExpressionUUID->"28fbe5c8-efee-4db9-a779-8ab6172ad822"],
Cell[49925, 1242, 3525, 73, 233, "Output",ExpressionUUID->"dcb2e058-968a-44e7-9c96-ee190cae8395"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53487, 1320, 455, 12, 30, "Input",ExpressionUUID->"95fc332e-19bd-464a-b3be-00683d708619"],
Cell[53945, 1334, 238, 3, 34, "Output",ExpressionUUID->"b0e4881e-4aeb-46bd-abf9-a6aef4bce70e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54220, 1342, 377, 9, 30, "Input",ExpressionUUID->"a56d1f11-36bf-49cd-af7a-9a6a0028aba7"],
Cell[54600, 1353, 170, 2, 34, "Output",ExpressionUUID->"3f2452bc-98df-4244-84d9-19339c7499c9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54807, 1360, 751, 23, 30, "Input",ExpressionUUID->"76a18611-21e6-4cf3-bfe9-f41dd1eca8ad"],
Cell[55561, 1385, 313, 7, 34, "Output",ExpressionUUID->"1f6eea4e-5469-453c-89f3-7ead131e4e5f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55911, 1397, 1565, 46, 73, "Input",ExpressionUUID->"3fb945fe-1e7b-434c-8e28-800346904237"],
Cell[57479, 1445, 6171, 121, 231, "Output",ExpressionUUID->"db3cdc31-d90a-456e-bd2d-f870a7620062"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[63699, 1572, 476, 6, 77, "Section",ExpressionUUID->"e3c7eec4-6eed-40d4-aa0b-e01463a458b8"],
Cell[64178, 1580, 702, 12, 58, "Text",ExpressionUUID->"c223bf43-ce4c-4f4d-b7ed-aa2d71220fe9"],
Cell[64883, 1594, 2187, 65, 73, "Input",ExpressionUUID->"d80c2df2-bb2f-4562-a231-127c40100eab"],
Cell[CellGroupData[{
Cell[67095, 1663, 284, 5, 30, "Input",ExpressionUUID->"7dee251a-e1a1-44d3-8499-ac0ff827b62f"],
Cell[67382, 1670, 554, 14, 53, "Output",ExpressionUUID->"e13f4f7a-707c-4cf8-9b22-eb0a78d33dfb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[67973, 1689, 231, 5, 30, "Input",ExpressionUUID->"bf394669-681d-4f5b-ba43-643699a45374"],
Cell[68207, 1696, 476, 15, 71, "Output",ExpressionUUID->"13888f43-b85a-4566-a72b-6f994d22b7d0"]
}, Open  ]],
Cell[68698, 1714, 666, 12, 58, "Text",ExpressionUUID->"e444d781-7041-4098-8354-314f7090060f"],
Cell[CellGroupData[{
Cell[69389, 1730, 609, 17, 30, "Input",ExpressionUUID->"aca15cab-f37b-40ee-9247-f80da0959947"],
Cell[CellGroupData[{
Cell[70023, 1751, 287, 6, 24, "Print",ExpressionUUID->"5eef6c0c-5efa-488e-bf69-4407eda1886a"],
Cell[70313, 1759, 285, 6, 24, "Print",ExpressionUUID->"ed0982d1-7d25-4c28-846a-d8cddc56fa86"],
Cell[70601, 1767, 287, 6, 24, "Print",ExpressionUUID->"d2e8ba0e-8dfb-4266-923d-51125ebfa3f2"],
Cell[70891, 1775, 285, 6, 24, "Print",ExpressionUUID->"ca1b04a5-30f6-408e-a482-de59069b1e32"],
Cell[71179, 1783, 284, 6, 24, "Print",ExpressionUUID->"013e7a51-f0d5-48f9-a5e6-5dc7884e7880"],
Cell[71466, 1791, 310, 7, 24, "Print",ExpressionUUID->"8b4244a2-1a88-425f-a3e8-94cd2f96f171"],
Cell[71779, 1800, 310, 7, 24, "Print",ExpressionUUID->"ad3fcf77-ecaf-424c-9a84-4e8bd844a952"],
Cell[72092, 1809, 310, 7, 24, "Print",ExpressionUUID->"1a4feda6-6118-4f90-ad08-0f839553ecb0"],
Cell[72405, 1818, 312, 7, 24, "Print",ExpressionUUID->"fa8d3561-5935-450d-8d72-61b914fe232f"]
}, Open  ]]
}, Open  ]],
Cell[72744, 1829, 647, 11, 35, "Text",ExpressionUUID->"cfc5154b-dcc1-4b89-b7f8-6d0dfbf50cf1"],
Cell[CellGroupData[{
Cell[73416, 1844, 2802, 74, 96, "Input",ExpressionUUID->"e831e4b1-81e4-4831-ae3b-7b0b6fe0908b"],
Cell[76221, 1920, 2445, 55, 242, "Output",ExpressionUUID->"cbfe7e39-8f2f-494f-830a-e14e95300bab"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78703, 1980, 536, 15, 30, "Input",ExpressionUUID->"0ab2931c-78ca-4573-81cb-26f1a9c383a9"],
Cell[79242, 1997, 2386, 54, 242, "Output",ExpressionUUID->"255e9ed4-41a2-47ea-8120-5c94f437ddad"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

